@@ -2,8 +2,8 @@
 #
 # Project    : ipv6calc
 # File       : autogen.sh
-# Version    : $Id: 71b74fb821ebf74140b2e04496a4fdc4551416de $
-# Copyright  : 2003-2015 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: 10075955bf6f63b0b4c307deaaa54a84ea975898 $
+# Copyright  : 2003-2019 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Information: autogeneration of projects with optional features
 
@@ -19,7 +19,16 @@ while [ "$1" != "$LAST" ]; do
 		;;
 	    '--all'|'-a')
 		shift
-		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-geoip --enable-ip2location --enable-dbip --enable-external --enable-mod_ipv6calc"
+		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-geoip --enable-ip2location --enable-dbip --enable-mmdb --enable-external --enable-mod_ipv6calc"
+		SKIP_STATIC=1
+		use_geoip=1
+		use_ip2location=1
+		use_dbip=1
+		use_external=1
+		;;
+	    '--ALL'|'-A')
+		shift
+		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-geoip --enable-ip2location --enable-dbip --enable-mmdb --with-geoip-dynamic --with-ip2location-dynamic --with-mmdb-dynamic --enable-external --enable-mod_ipv6calc"
 		SKIP_STATIC=1
 		use_geoip=1
 		use_ip2location=1
@@ -39,6 +48,19 @@ while [ "$1" != "$LAST" ]; do
 		use_geoip=1
 		use_geoip_dyn=1
 		;;
+	    '--mmdb'|'-m')
+		shift
+		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-mmdb"
+		SKIP_STATIC=1
+		use_mmdb=1
+		;;
+	    '--mmdb-dyn'|'-M')
+		shift
+		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-mmdb --with-mmdb-dynamic"
+		SKIP_STATIC=1
+		use_mmdb=1
+		use_mmdb_dyn=1
+		;;
 	    '--ip2location'|'-i')
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-ip2location"
@@ -98,11 +120,24 @@ while [ "$1" != "$LAST" ]; do
 		shift
 		USE_CLANG=1
 		;;
+	    '--m32')
+		shift
+		CFLAGS="$CFLAGS -m32"
+		;;
+	    '--relax')
+		shift
+		RELAX=1
+		;;
 	    '-?'|'-h'|'--help')
 		echo "Supported options:"
 		echo "   -?|-h|--help        : this help"
 		echo "   -n|--no-make        : stop before running 'make'"
 		echo "   -a|--all            : enable GeoIP/IP2Location/db-ip.com/External/mod_ipv6calc support"
+		echo "   -A|--ALL            : enable GeoIP/IP2Location/db-ip.com/External/mod_ipv6calc support with dynamic library support"
+		echo "   -m|--mmdb           : enable MaxMindDB support (GeoIP/db-ip.com)"
+		echo "   --mmdb-dyn|-M       : switch to dynamic library loading of MaxMindDB"
+		echo "   --disable-geoip2    : disable MaxMindDB support for GeoIP"
+		echo "   --disable-dbip2     : disable MaxMindDB support for db-ip.com"
 		echo "   -g|--geoip          : enable GeoIP support"
 		echo "   --geoip-dyn|-G      : switch to dynamic library loading of GeoIP"
 		echo "   -i|--ip2location    : enable IP2Location support"
@@ -117,11 +152,15 @@ while [ "$1" != "$LAST" ]; do
 		echo "   --no-static-build   : skip static build"
 		echo "   --no-test           : skip 'make test'"
 		echo "   --clang             : use 'clang' instead of default (usually 'gcc')"
+		echo "   --m32               : compile for 32-bit"
+		echo "   --relax             : don't stop on compiler warnings"
 		exit 1
 		;;
 	    *)
-		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE $1"
-		shift
+		if [ -n "$1" ]; then
+			OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE $1"
+			shift
+		fi
 		;;
 	esac
 done
@@ -140,6 +179,12 @@ if [ "$use_ip2location" = "1" ]; then
 	fi
 fi
 
+if [ "$RELAX" = "1" ]; then
+	if ! echo "$OPTIONS_CONFIGURE" | grep -q 'disable-compiler-warning-to-error'; then
+		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --disable-compiler-warning-to-error"
+	fi
+fi
+
 if [ -f Makefile ]; then
 	echo "*** cleanup"
 	make autoclean
@@ -161,7 +206,7 @@ echo "*** run: autoconf"
 autoconf || exit 1
 
 echo "*** run: configure, options: $OPTIONS_CONFIGURE $*"
-LDFLAGS="$LDFLAGS -Wl,--as-needed" ./configure --bindir=/usr/bin --mandir=/usr/share/man $OPTIONS_CONFIGURE $* || exit 1
+CFLAGS="$CFLAGS" LDFLAGS="$LDFLAGS -Wl,--as-needed" ./configure --bindir=/usr/bin --mandir=/usr/share/man $OPTIONS_CONFIGURE $* || exit 1
 
 if [ "$flag_no_make" = "1" ]; then
 	echo
