@@ -1,8 +1,8 @@
 /*
  * Project       : ipv6calc
  * File          : dbipv6_assignment.h
- * Version       : $Id: 510bf42d9740b4d8f6b79c721e7316b1b2674e25 $
- * Generated     : 20170625-094748+0200 CEST
+ * Version       : $Id: a1cdccd3c82f697be3a7d43cc3190bb8782b5ad3 $
+ * Generated     : 20190405-060250+0200 CEST
  * Data copyright: IANA ARIN RIPENCC APNIC LACNIC AFRINIC
  *
  * Information:
@@ -11,8 +11,8 @@
 
 #include "databases/lib/libipv6calc_db_wrapper_BuiltIn.h"
 
-static const char* dbipv6addr_registry_status __attribute__ ((__unused__)) = "AFRINIC/20170625 APNIC/20170624 ARIN/20170625 IANA/20170104 LACNIC/20170623 LISP/20170625 RIPENCC/20170624";
-static const time_t dbipv6addr_registry_unixtime __attribute__ ((__unused__)) = 1498376868;
+static const char* dbipv6addr_registry_status __attribute__ ((__unused__)) = "AFRINIC/20190403 APNIC/20190404 ARIN/20190404 IANA/20190312 LACNIC/20190404 LISP/20190405 RIPENCC/20190404";
+static const time_t dbipv6addr_registry_unixtime __attribute__ ((__unused__)) = 1554436970;
 
 static const s_ipv6addr_assignment dbipv6addr_assignment[] = {
 	//ipv6_00_31, ipv6_32_63, mask_00_31, mask_32_63, mask_length, registry  
@@ -53,7 +53,7 @@ static const s_ipv6addr_assignment dbipv6addr_assignment[] = {
 	{ 0x20012000, 0x00000000, 0xfffff000, 0x00000000,  20, REGISTRY_RIPENCC    },
 	{ 0x20013000, 0x00000000, 0xfffff800, 0x00000000,  21, REGISTRY_RIPENCC    },
 	{ 0x20013800, 0x00000000, 0xfffffc00, 0x00000000,  22, REGISTRY_RIPENCC    },
-	{ 0x20013c00, 0x00000000, 0xfffffc00, 0x00000000,  22, REGISTRY_IANA       },
+	{ 0x20013c00, 0x00000000, 0xfffffc00, 0x00000000,  22, REGISTRY_RIPENCC    },
 	{ 0x20014000, 0x00000000, 0xfffffe00, 0x00000000,  23, REGISTRY_RIPENCC    },
 	{ 0x20014200, 0x00000000, 0xfffffe00, 0x00000000,  23, REGISTRY_AFRINIC    },
 	{ 0x20014400, 0x00000000, 0xfffffe00, 0x00000000,  23, REGISTRY_APNIC      },
@@ -164,8 +164,10 @@ static const s_ipv6addr_info dbipv6addr_info[] = {
 	{ 0x261000d0, 0x11500000, 0xffffffff, 0xffff0000,  48, "LISP#spisati-xtr-2" },
 	{ 0x261000d0, 0x11510000, 0xffffffff, 0xffff0000,  48, "LISP#lprat-xtr" },
 	{ 0x261000d0, 0x11520000, 0xffffffff, 0xffff0000,  48, "LISP#triple-xtr" },
-	{ 0x261000d0, 0x11530000, 0xffffffff, 0xffff0000,  48, "LISP#columbia-xtr" },
+	{ 0x261000d0, 0x11530000, 0xffffffff, 0xffff0000,  48, "LISP#cmich-xtr" },
 	{ 0x261000d0, 0x11540000, 0xffffffff, 0xffff0000,  48, "LISP#rtajvar-xtr" },
+	{ 0x261000d0, 0x11550000, 0xffffffff, 0xffff0000,  48, "LISP#snicholas-xtr" },
+	{ 0x261000d0, 0x11560000, 0xffffffff, 0xffff0000,  48, "LISP#nist-xtr" },
 	{ 0x261000d0, 0x12020000, 0xffffffff, 0xffff0000,  48, "LISP#icox-xtr" },
 	{ 0x261000d0, 0x12030000, 0xffffffff, 0xffff0000,  48, "LISP#gregg-xtr" },
 	{ 0x261000d0, 0x12050000, 0xffffffff, 0xffff0000,  48, "LISP#snoble-xtr" },
@@ -213,7 +215,10 @@ static const s_ipv6addr_info dbipv6addr_info[] = {
 	{ 0x261000d0, 0x12340000, 0xffffffff, 0xffff0000,  48, "LISP#jcolin-xtr" },
 	{ 0x261000d0, 0x12350000, 0xffffffff, 0xffff0000,  48, "LISP#rbonnell-xtr" },
 	{ 0x261000d0, 0x12360000, 0xffffffff, 0xffff0000,  48, "LISP#jalberti-xtr" },
-	{ 0x261000d0, 0x12370000, 0xffffffff, 0xffff0000,  48, "LISP#mmaurice-xtr" },
+	{ 0x261000d0, 0x12370000, 0xffffffff, 0xffff0000,  48, "LISP#cisco-natal2-xtr" },
+	{ 0x261000d0, 0x12380000, 0xffffffff, 0xffff0000,  48, "LISP#lfiegl-xtr" },
+	{ 0x261000d0, 0x12390000, 0xffffffff, 0xffff0000,  48, "LISP#upc-arin-xtr" },
+	{ 0x261000d0, 0x123a0000, 0xffffffff, 0xffff0000,  48, "LISP#azure-xtr" },
 	{ 0x261000d0, 0x13020000, 0xffffffff, 0xffff0000,  48, "LISP#wnellis-xtr" },
 	{ 0x261000d0, 0x13030000, 0xffffffff, 0xffff0000,  48, "LISP#darrel-xtr" },
 	{ 0x261000d0, 0x13040000, 0xffffffff, 0xffff0000,  48, "LISP#vaf-xtr" },
@@ -394,8 +399,6 @@ static const s_ipv6addr_info dbipv6addr_info[] = {
 	{ 0x261000d0, 0x219f0000, 0xffffffff, 0xffff0000,  48, "LISP#fuhge-xtr" },
 	{ 0x261000d0, 0x21a00000, 0xffffffff, 0xffff0000,  48, "LISP#isah-xtr" },
 	{ 0x261000d0, 0x21a10000, 0xffffffff, 0xffff0000,  48, "LISP#lovison-xtr" },
-	{ 0x261000d0, 0x21a10101, 0xffffffff, 0xffffffff,  64, "LISP#lovison-xtr" },
-	{ 0x261000d0, 0x21a10103, 0xffffffff, 0xffffffff,  64, "LISP#lovison-xtr" },
 	{ 0x261000d0, 0x21a20000, 0xffffffff, 0xffff0000,  48, "LISP#jens-xtr" },
 	{ 0x261000d0, 0x21a30000, 0xffffffff, 0xffff0000,  48, "LISP#naundorf-xtr" },
 	{ 0x261000d0, 0x21a40000, 0xffffffff, 0xffff0000,  48, "LISP#leon-xtr" },
@@ -461,75 +464,72 @@ static const s_ipv6addr_info dbipv6addr_info[] = {
 	{ 0x261000d0, 0x21e00000, 0xffffffff, 0xffff0000,  48, "LISP#jclayton-xtr" },
 	{ 0x261000d0, 0x21e10000, 0xffffffff, 0xffff0000,  48, "LISP#niek-xtr" },
 	{ 0x261000d0, 0x21e20000, 0xffffffff, 0xffff0000,  48, "LISP#mbar-xtr" },
-	{ 0x261000d0, 0x21e30000, 0xffffffff, 0xffff0000,  48, "LISP#ssanders-xtr" },
-	{ 0x261000d0, 0x21e40000, 0xffffffff, 0xffff0000,  48, "LISP#eahlers-xtr" },
-	{ 0x261000d0, 0x21e50000, 0xffffffff, 0xffff0000,  48, "LISP#dknobloch-xtr" },
-	{ 0x261000d0, 0x21e60000, 0xffffffff, 0xffff0000,  48, "LISP#hschutt-xtr" },
-	{ 0x261000d0, 0x21e70000, 0xffffffff, 0xffff0000,  48, "LISP#lalber-xtr" },
-	{ 0x261000d0, 0x21e80000, 0xffffffff, 0xffff0000,  48, "LISP#dwilmer-xtr" },
-	{ 0x261000d0, 0x21e90000, 0xffffffff, 0xffff0000,  48, "LISP#sraisl-xtr" },
-	{ 0x261000d0, 0x21ea0000, 0xffffffff, 0xffff0000,  48, "LISP#mbernhardt-xtr" },
-	{ 0x261000d0, 0x21eb0000, 0xffffffff, 0xffff0000,  48, "LISP#jguther-xtr" },
-	{ 0x261000d0, 0x21ec0000, 0xffffffff, 0xffff0000,  48, "LISP#jguenther-xtr" },
+	{ 0x261000d0, 0x21e30000, 0xffffffff, 0xffff0000,  48, "LISP#lsd-xtr" },
+	{ 0x261000d0, 0x21e40000, 0xffffffff, 0xffff0000,  48, "LISP#rfurda-xtr" },
+	{ 0x261000d0, 0x21e50000, 0xffffffff, 0xffff0000,  48, "LISP#gmaricau-xtr" },
+	{ 0x261000d0, 0x21e70000, 0xffffffff, 0xffff0000,  48, "LISP#dzeitler-xtr" },
+	{ 0x261000d0, 0x21e80000, 0xffffffff, 0xffff0000,  48, "LISP#garndt-xtr" },
+	{ 0x261000d0, 0x21e90000, 0xffffffff, 0xffff0000,  48, "LISP#jpreuss-xtr" },
+	{ 0x261000d0, 0x21ea0000, 0xffffffff, 0xffff0000,  48, "LISP#smondwurf-xtr" },
+	{ 0x261000d0, 0x21eb0000, 0xffffffff, 0xffff0000,  48, "LISP#tbonitz-xtr" },
+	{ 0x261000d0, 0x21ec0000, 0xffffffff, 0xffff0000,  48, "LISP#cisco-natal1-xtr" },
 	{ 0x261000d0, 0x21ed0000, 0xffffffff, 0xffff0000,  48, "LISP#cglasmeyer-xtr" },
-	{ 0x261000d0, 0x21ee0000, 0xffffffff, 0xffff0000,  48, "LISP#rsiegel-xtr" },
-	{ 0x261000d0, 0x21ef0000, 0xffffffff, 0xffff0000,  48, "LISP#hbeck-xtr" },
-	{ 0x261000d0, 0x21f10000, 0xffffffff, 0xffff0000,  48, "LISP#kwulff-xtr" },
+	{ 0x261000d0, 0x21ee0000, 0xffffffff, 0xffff0000,  48, "LISP#rengel-xtr" },
+	{ 0x261000d0, 0x21ef0000, 0xffffffff, 0xffff0000,  48, "LISP#hgojny-xtr" },
+	{ 0x261000d0, 0x21f10000, 0xffffffff, 0xffff0000,  48, "LISP#rkohn-xtr" },
 	{ 0x261000d0, 0x21f20000, 0xffffffff, 0xffff0000,  48, "LISP#jpkoegeler-xtr" },
-	{ 0x261000d0, 0x21f30000, 0xffffffff, 0xffff0000,  48, "LISP#clangbehn-xtr" },
-	{ 0x261000d0, 0x21f40000, 0xffffffff, 0xffff0000,  48, "LISP#degger-xtr" },
-	{ 0x261000d0, 0x21f50000, 0xffffffff, 0xffff0000,  48, "LISP#rmalbrecht-xtr" },
+	{ 0x261000d0, 0x21f30000, 0xffffffff, 0xffff0000,  48, "LISP#gniederwimmer-xtr" },
+	{ 0x261000d0, 0x21f50000, 0xffffffff, 0xffff0000,  48, "LISP#mmikulenas-xtr" },
 	{ 0x261000d0, 0x21f60000, 0xffffffff, 0xffff0000,  48, "LISP#cbretterhofer-xtr" },
-	{ 0x261000d0, 0x21f70000, 0xffffffff, 0xffff0000,  48, "LISP#gheinen-xtr" },
-	{ 0x261000d0, 0x21f80000, 0xffffffff, 0xffff0000,  48, "LISP#twiederhold-xtr" },
+	{ 0x261000d0, 0x21f70000, 0xffffffff, 0xffff0000,  48, "LISP#mgoebel-xtr" },
+	{ 0x261000d0, 0x21f80000, 0xffffffff, 0xffff0000,  48, "LISP#bmorcinkowski-xtr" },
 	{ 0x261000d0, 0x21f90000, 0xffffffff, 0xffff0000,  48, "LISP#jbaumann-xtr" },
-	{ 0x261000d0, 0x21fa0000, 0xffffffff, 0xffff0000,  48, "LISP#sscheib-xtr" },
-	{ 0x261000d0, 0x21fb0000, 0xffffffff, 0xffff0000,  48, "LISP#tluttgert-xtr" },
-	{ 0x261000d0, 0x21fc0000, 0xffffffff, 0xffff0000,  48, "LISP#dkoppen-xtr" },
+	{ 0x261000d0, 0x21fa0000, 0xffffffff, 0xffff0000,  48, "LISP#mfey-xtr" },
+	{ 0x261000d0, 0x21fb0000, 0xffffffff, 0xffff0000,  48, "LISP#mmuller-xtr" },
+	{ 0x261000d0, 0x21fc0000, 0xffffffff, 0xffff0000,  48, "LISP#rjud-xtr" },
 	{ 0x261000d0, 0x21fd0000, 0xffffffff, 0xffff0000,  48, "LISP#theinz-xtr" },
-	{ 0x261000d0, 0x21fe0000, 0xffffffff, 0xffff0000,  48, "LISP#tsteen-xtr" },
-	{ 0x261000d0, 0x22000000, 0xffffffff, 0xffff0000,  48, "LISP#cheimanns-xtr" },
+	{ 0x261000d0, 0x21fe0000, 0xffffffff, 0xffff0000,  48, "LISP#fzahn-xtr" },
+	{ 0x261000d0, 0x22000000, 0xffffffff, 0xffff0000,  48, "LISP#ahugi-xtr" },
 	{ 0x261000d0, 0x22010000, 0xffffffff, 0xffff0000,  48, "LISP#sukiyakiproj-xtr" },
-	{ 0x261000d0, 0x22020000, 0xffffffff, 0xffff0000,  48, "LISP#tstempel-xtr" },
+	{ 0x261000d0, 0x22020000, 0xffffffff, 0xffff0000,  48, "LISP#jdechert-xtr" },
 	{ 0x261000d0, 0x22030000, 0xffffffff, 0xffff0000,  48, "LISP#crothlander-xtr" },
-	{ 0x261000d0, 0x22040000, 0xffffffff, 0xffff0000,  48, "LISP#isonmezglu-xtr" },
-	{ 0x261000d0, 0x22050000, 0xffffffff, 0xffff0000,  48, "LISP#rlehmann-xtr" },
-	{ 0x261000d0, 0x22060000, 0xffffffff, 0xffff0000,  48, "LISP#rbeie-xtr" },
-	{ 0x261000d0, 0x22070000, 0xffffffff, 0xffff0000,  48, "LISP#hosius-xtr" },
-	{ 0x261000d0, 0x22080000, 0xffffffff, 0xffff0000,  48, "LISP#hbuchholz-xtr" },
-	{ 0x261000d0, 0x22090000, 0xffffffff, 0xffff0000,  48, "LISP#bgeiger-xtr" },
-	{ 0x261000d0, 0x220a0000, 0xffffffff, 0xffff0000,  48, "LISP#bbusch-xtr" },
-	{ 0x261000d0, 0x220b0000, 0xffffffff, 0xffff0000,  48, "LISP#flyingcircus-xtr" },
-	{ 0x261000d0, 0x220c0000, 0xffffffff, 0xffff0000,  48, "LISP#jfriedrich-xtr" },
-	{ 0x261000d0, 0x220d0000, 0xffffffff, 0xffff0000,  48, "LISP#ddroop-xtr" },
-	{ 0x261000d0, 0x220e0000, 0xffffffff, 0xffff0000,  48, "LISP#broth-xtr" },
-	{ 0x261000d0, 0x220f0000, 0xffffffff, 0xffff0000,  48, "LISP#sbellstedt-xtr" },
-	{ 0x261000d0, 0x22100000, 0xffffffff, 0xffff0000,  48, "LISP#kjaschultowski-xtr" },
-	{ 0x261000d0, 0x22110000, 0xffffffff, 0xffff0000,  48, "LISP#mbuescher-xtr" },
-	{ 0x261000d0, 0x22120000, 0xffffffff, 0xffff0000,  48, "LISP#wheinze-xtr" },
-	{ 0x261000d0, 0x22130000, 0xffffffff, 0xffff0000,  48, "LISP#ekoncel-xtr" },
+	{ 0x261000d0, 0x22050000, 0xffffffff, 0xffff0000,  48, "LISP#wvanlid-xtr" },
+	{ 0x261000d0, 0x22060000, 0xffffffff, 0xffff0000,  48, "LISP#upc-oor-xtr" },
+	{ 0x261000d0, 0x22080000, 0xffffffff, 0xffff0000,  48, "LISP#tivano-software-xtr" },
+	{ 0x261000d0, 0x22090000, 0xffffffff, 0xffff0000,  48, "LISP#ngunther-xtr" },
+	{ 0x261000d0, 0x220a0000, 0xffffffff, 0xffff0000,  48, "LISP#gthor-xtr" },
+	{ 0x261000d0, 0x220b0000, 0xffffffff, 0xffff0000,  48, "LISP#wonken-xtr" },
+	{ 0x261000d0, 0x220d0000, 0xffffffff, 0xffff0000,  48, "LISP#tzapala-xtr" },
+	{ 0x261000d0, 0x220e0000, 0xffffffff, 0xffff0000,  48, "LISP#rmller-xtr" },
+	{ 0x261000d0, 0x22100000, 0xffffffff, 0xffff0000,  48, "LISP#feul-xtr" },
+	{ 0x261000d0, 0x22110000, 0xffffffff, 0xffff0000,  48, "LISP#asunnetci-xtr" },
+	{ 0x261000d0, 0x22130000, 0xffffffff, 0xffff0000,  48, "LISP#dfett-xtr" },
 	{ 0x261000d0, 0x22140000, 0xffffffff, 0xffff0000,  48, "LISP#mklingspor-xtr" },
-	{ 0x261000d0, 0x22150000, 0xffffffff, 0xffff0000,  48, "LISP#gloss-xtr" },
-	{ 0x261000d0, 0x22160000, 0xffffffff, 0xffff0000,  48, "LISP#koandreasson-xtr" },
+	{ 0x261000d0, 0x22150000, 0xffffffff, 0xffff0000,  48, "LISP#gsanjay-xtr" },
+	{ 0x261000d0, 0x22160000, 0xffffffff, 0xffff0000,  48, "LISP#tkoch-xtr" },
 	{ 0x261000d0, 0x22170000, 0xffffffff, 0xffff0000,  48, "LISP#hrenz-xtr" },
-	{ 0x261000d0, 0x22180000, 0xffffffff, 0xffff0000,  48, "LISP#uschledorn-xtr" },
+	{ 0x261000d0, 0x22180000, 0xffffffff, 0xffff0000,  48, "LISP#blawall-xtr" },
 	{ 0x261000d0, 0x22190000, 0xffffffff, 0xffff0000,  48, "LISP#unitbv-xtr" },
 	{ 0x261000d0, 0x222a0000, 0xffffffff, 0xffff0000,  48, "LISP#hketele-xtr" },
-	{ 0x261000d0, 0x222b0000, 0xffffffff, 0xffff0000,  48, "LISP#gevgrafov-xtr" },
-	{ 0x261000d0, 0x222c0000, 0xffffffff, 0xffff0000,  48, "LISP#jriechers-xtr" },
-	{ 0x261000d0, 0x222d0000, 0xffffffff, 0xffff0000,  48, "LISP#ebent-xtr" },
-	{ 0x261000d0, 0x222e0000, 0xffffffff, 0xffff0000,  48, "LISP#eadeva-xtr" },
+	{ 0x261000d0, 0x222b0000, 0xffffffff, 0xffff0000,  48, "LISP#rdchragner-xtr" },
+	{ 0x261000d0, 0x222c0000, 0xffffffff, 0xffff0000,  48, "LISP#mamin-xtr" },
+	{ 0x261000d0, 0x222e0000, 0xffffffff, 0xffff0000,  48, "LISP#twittenberg-xtr" },
 	{ 0x261000d0, 0x222f0000, 0xffffffff, 0xffff0000,  48, "LISP#bwieder-xtr" },
-	{ 0x261000d0, 0x22300000, 0xffffffff, 0xffff0000,  48, "LISP#mmikulenas-xtr" },
-	{ 0x261000d0, 0x22310000, 0xffffffff, 0xffff0000,  48, "LISP#mgusek-xtr" },
-	{ 0x261000d0, 0x22320000, 0xffffffff, 0xffff0000,  48, "LISP#logima-xtr" },
+	{ 0x261000d0, 0x22300000, 0xffffffff, 0xffff0000,  48, "LISP#sbethge-xtr" },
+	{ 0x261000d0, 0x22310000, 0xffffffff, 0xffff0000,  48, "LISP#jdornauf-xtr" },
 	{ 0x261000d0, 0x22330000, 0xffffffff, 0xffff0000,  48, "LISP#mmiller-xtr" },
-	{ 0x261000d0, 0x22340000, 0xffffffff, 0xffff0000,  48, "LISP#jschlingensiepen-xtr" },
-	{ 0x261000d0, 0x22350000, 0xffffffff, 0xffff0000,  48, "LISP#gmassa-xtr" },
+	{ 0x261000d0, 0x22340000, 0xffffffff, 0xffff0000,  48, "LISP#cfertig-xtr" },
+	{ 0x261000d0, 0x22350000, 0xffffffff, 0xffff0000,  48, "LISP#jkatolla-xtr" },
 	{ 0x261000d0, 0x22360000, 0xffffffff, 0xffff0000,  48, "LISP#freenet-xtr" },
-	{ 0x261000d0, 0x22370000, 0xffffffff, 0xffff0000,  48, "LISP#dietausendsassa-xtr" },
-	{ 0x261000d0, 0x22380000, 0xffffffff, 0xffff0000,  48, "LISP#niek_van_der_ven-xtr" },
+	{ 0x261000d0, 0x22370000, 0xffffffff, 0xffff0000,  48, "LISP#nweissbach-xtr" },
+	{ 0x261000d0, 0x22380000, 0xffffffff, 0xffff0000,  48, "LISP#owas-xtr" },
 	{ 0x261000d0, 0x22390000, 0xffffffff, 0xffff0000,  48, "LISP#rspickers-xtr" },
+	{ 0x261000d0, 0x223a0000, 0xffffffff, 0xffff0000,  48, "LISP#pcech-xtr" },
+	{ 0x261000d0, 0x223b0000, 0xffffffff, 0xffff0000,  48, "LISP#cpalm-xtr" },
+	{ 0x261000d0, 0x223c0000, 0xffffffff, 0xffff0000,  48, "LISP#asellmann-xtr" },
+	{ 0x261000d0, 0x223d0000, 0xffffffff, 0xffff0000,  48, "LISP#mluckert-xtr" },
+	{ 0x261000d0, 0x223e0000, 0xffffffff, 0xffff0000,  48, "LISP#tzimmermann-xtr" },
+	{ 0x261000d0, 0x223f0000, 0xffffffff, 0xffff0000,  48, "LISP#dpeshev-xtr" },
 	{ 0x261000d0, 0x31000000, 0xffffffff, 0xffff0000,  48, "LISP#iij-xtr" },
 	{ 0x261000d0, 0x32000000, 0xffffffff, 0xffff0000,  48, "LISP#hughes-xtr" },
 	{ 0x261000d0, 0x32010000, 0xffffffff, 0xffff0000,  48, "LISP#apan-xtr" },
@@ -573,8 +573,12 @@ static const s_ipv6addr_info dbipv6addr_info[] = {
 	{ 0x261000d0, 0x32280000, 0xffffffff, 0xffff0000,  48, "LISP#yshiin-xtr" },
 	{ 0x261000d0, 0x32290000, 0xffffffff, 0xffff0000,  48, "LISP#tao-networks2-xtr" },
 	{ 0x261000d0, 0x322a0000, 0xffffffff, 0xffff0000,  48, "LISP#rdines-xtr" },
-	{ 0x261000d0, 0x322b0000, 0xffffffff, 0xffff0000,  48, "LISP#tosterbe1-xtr" },
-	{ 0x261000d0, 0x322c0000, 0xffffffff, 0xffff0000,  48, "LISP#jzhang-xtr" },
+	{ 0x261000d0, 0x322b0000, 0xffffffff, 0xffff0000,  48, "LISP#upc-oor2-xtr" },
+	{ 0x261000d0, 0x322c0000, 0xffffffff, 0xffff0000,  48, "LISP#ietf100-xtr" },
+	{ 0x261000d0, 0x322d0000, 0xffffffff, 0xffff0000,  48, "LISP#sukiyaki-proj-xtr" },
+	{ 0x261000d0, 0x322e0000, 0xffffffff, 0xffff0000,  48, "LISP#sukiyaki2-proj-xtr" },
+	{ 0x261000d0, 0x322f0000, 0xffffffff, 0xffff0000,  48, "LISP#gtja-xtr" },
+	{ 0x261000d0, 0x32300000, 0xffffffff, 0xffff0000,  48, "LISP#hcmus-xtr" },
 	{ 0x261000d0, 0x323f0000, 0xffffffff, 0xffff0000,  48, "LISP#gs9591-xtr" },
 	{ 0x261000d0, 0x50000000, 0xffffffff, 0xffff0000,  48, "LISP#ufba-xtr" },
 	{ 0x261000d0, 0xface0000, 0xffffffff, 0xffff0000,  48, "LISP#facebook-xtr-2" },
