@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper.h
- * Version    : $Id: 0f847284fb560c0a6eaaff36fbc71e0e467d5ab7 $
- * Copyright  : 2013-2017 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 39126b6a85ac84639bccd67cff1774cd332e8885 $
+ * Copyright  : 2013-2019 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc_db_wrapper.c
@@ -12,15 +12,15 @@
 #include <db.h>
 #endif // HAVE_BERKELEY_DB_SUPPORT
 
-#ifndef _libipv6calc_db_wrapper_h
-
-#define _libipv6calc_db_wrapper_h 1
-
 #include "ipv6calctypes.h"
 #include "libmac.h"
 #include "libipv4addr.h"
 #include "libipv6addr.h"
 
+#ifndef _libipv6calc_db_wrapper_h
+
+#define _libipv6calc_db_wrapper_h 1
+
 extern uint32_t wrapper_features;
 extern uint32_t wrapper_features_by_source[];
 extern uint32_t wrapper_features_by_source_implemented[];
@@ -28,7 +28,7 @@ extern uint32_t wrapper_features_by_source_implemented[];
 #define IPV6CALC_PROTO_IPV4				4
 #define IPV6CALC_PROTO_IPV6				6
 
-// define generic feature numbers
+// define generic feature numbers (max: 24)
 #define IPV6CALC_DB_FEATURE_NUM_MIN			0
 #define IPV6CALC_DB_FEATURE_NUM_AS_TO_REGISTRY		0
 #define IPV6CALC_DB_FEATURE_NUM_CC_TO_REGISTRY		1
@@ -47,7 +47,9 @@ extern uint32_t wrapper_features_by_source_implemented[];
 #define IPV6CALC_DB_FEATURE_NUM_IEEE_TO_INFO		14
 #define IPV6CALC_DB_FEATURE_NUM_IPV4_TO_INFO		15
 #define IPV6CALC_DB_FEATURE_NUM_IPV6_TO_INFO		16
-#define IPV6CALC_DB_FEATURE_NUM_MAX			IPV6CALC_DB_FEATURE_NUM_IPV6_TO_INFO
+#define IPV6CALC_DB_FEATURE_NUM_IPV4_TO_GEONAMEID	17
+#define IPV6CALC_DB_FEATURE_NUM_IPV6_TO_GEONAMEID	18
+#define IPV6CALC_DB_FEATURE_NUM_MAX			IPV6CALC_DB_FEATURE_NUM_IPV6_TO_GEONAMEID
 
 // define generic features
 #define IPV6CALC_DB_AS_TO_REGISTRY		(1 << IPV6CALC_DB_FEATURE_NUM_AS_TO_REGISTRY)
@@ -75,16 +77,28 @@ extern uint32_t wrapper_features_by_source_implemented[];
 #define IPV6CALC_DB_IPV4_TO_INFO		(1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_INFO)
 #define IPV6CALC_DB_IPV6_TO_INFO		(1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_INFO)
 
+#define IPV6CALC_DB_IPV4_TO_GEONAMEID		(1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_GEONAMEID)
+#define IPV6CALC_DB_IPV6_TO_GEONAMEID		(1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_GEONAMEID)
+
+// define combination of generic features
+#define IPV6CALC_DB_IP_TO_AS			(IPV6CALC_DB_IPV4_TO_AS        | IPV6CALC_DB_IPV6_TO_AS       )
+#define IPV6CALC_DB_IP_TO_COUNTRY		(IPV6CALC_DB_IPV4_TO_COUNTRY   | IPV6CALC_DB_IPV6_TO_COUNTRY  )
+#define IPV6CALC_DB_IP_TO_CC			(IPV6CALC_DB_IPV4_TO_CC        | IPV6CALC_DB_IPV6_TO_CC       )
+#define IPV6CALC_DB_IP_TO_CITY			(IPV6CALC_DB_IPV4_TO_CITY      | IPV6CALC_DB_IPV6_TO_CITY     )
+#define IPV6CALC_DB_IP_TO_REGION		(IPV6CALC_DB_IPV4_TO_REGION    | IPV6CALC_DB_IPV6_TO_REGION   )
+#define IPV6CALC_DB_IP_TO_GEONAMEID		(IPV6CALC_DB_IPV4_TO_GEONAMEID | IPV6CALC_DB_IPV6_TO_GEONAMEID)
 
 // define database specific generic features
 #define IPV6CALC_DB_GEOIP_IPV4			0x01000000
 #define IPV6CALC_DB_GEOIP_IPV6			0x02000000
+#define IPV6CALC_DB_GEOIP			(IPV6CALC_DB_GEOIP_IPV4 | IPV6CALC_DB_GEOIP_IPV6)
 
 #define IPV6CALC_DB_IP2LOCATION_IPV4		0x04000000
 #define IPV6CALC_DB_IP2LOCATION_IPV6		0x08000000
 
 #define IPV6CALC_DB_DBIP_IPV4			0x10000000
 #define IPV6CALC_DB_DBIP_IPV6			0x20000000
+#define IPV6CALC_DB_DBIP			(IPV6CALC_DB_DBIP_IPV4 | IPV6CALC_DB_DBIP_IPV6)
 
 #define IPV6CALC_DB_EXTERNAL_IPV4		0x40000000
 #define IPV6CALC_DB_EXTERNAL_IPV6		0x80000000
@@ -114,6 +128,8 @@ static const s_formatoption ipv6calc_db_features[] = {
 	{ IPV6CALC_DB_IEEE_TO_INFO	, "DB_IEEE"		, "IEEE/OUI/OUI36 Vendor database" },
 	{ IPV6CALC_DB_IPV4_TO_INFO	, "DB_IPV4_INFO"	, "IPv4 additional information" },
 	{ IPV6CALC_DB_IPV6_TO_INFO	, "DB_IPV6_INFO"	, "IPv6 additional information" },
+	{ IPV6CALC_DB_IPV4_TO_GEONAMEID	, "DB_IPV4_GEONAMEID"	, "IPv4 GeonameID" },
+	{ IPV6CALC_DB_IPV6_TO_GEONAMEID	, "DB_IPV6_GEONAMEID"	, "IPv6 GeonameID" },
 };
 
 // data sources
@@ -121,13 +137,15 @@ static const s_formatoption ipv6calc_db_features[] = {
 
 #define IPV6CALC_DB_SOURCE_MIN			1
 
-#define IPV6CALC_DB_SOURCE_GEOIP		1
+#define IPV6CALC_DB_SOURCE_GEOIP2		1
 #define IPV6CALC_DB_SOURCE_IP2LOCATION		2
-#define IPV6CALC_DB_SOURCE_DBIP			3
-#define IPV6CALC_DB_SOURCE_EXTERNAL		4
-#define IPV6CALC_DB_SOURCE_BUILTIN		5
+#define IPV6CALC_DB_SOURCE_DBIP2		3
+#define IPV6CALC_DB_SOURCE_GEOIP		4
+#define IPV6CALC_DB_SOURCE_DBIP			5
+#define IPV6CALC_DB_SOURCE_EXTERNAL		6
+#define IPV6CALC_DB_SOURCE_BUILTIN		7
 
-#define IPV6CALC_DB_SOURCE_MAX			5
+#define IPV6CALC_DB_SOURCE_MAX			7
 
 #define IPV6CALC_DB_PRIO_MAX			IPV6CALC_DB_SOURCE_MAX
 
@@ -139,8 +157,10 @@ typedef struct {
 
 static const s_data_sources data_sources[] = {
 	{ IPV6CALC_DB_SOURCE_GEOIP	, "GeoIP"      , "GeoIP"       },
+	{ IPV6CALC_DB_SOURCE_GEOIP2	, "GeoIP(MaxMindDB)"    , "GeoIP2"      },
 	{ IPV6CALC_DB_SOURCE_IP2LOCATION, "IP2Location", "IP2Location" },
 	{ IPV6CALC_DB_SOURCE_DBIP	, "db-ip.com"  , "DBIP"        },
+	{ IPV6CALC_DB_SOURCE_DBIP2	, "db-ip.com(MaxMindDB)", "DBIP2"       },
 	{ IPV6CALC_DB_SOURCE_EXTERNAL	, "External"   , "External"    },
 	{ IPV6CALC_DB_SOURCE_BUILTIN	, "BuiltIn"    , "BuiltIn"     },
 };
@@ -162,6 +182,92 @@ typedef struct {
 } db_file_desc2;
 
 
+// abstract structure for geolocation information
+// string limits taken from from https://db-ip.com/db/
+// and IP2Location
+#define IPV6CALC_DB_SIZE_COUNTRY_CODE	2+1
+#define IPV6CALC_DB_SIZE_COUNTRY_LONG	80+1
+#define IPV6CALC_DB_SIZE_CONTINENT_CODE	2+1
+#define IPV6CALC_DB_SIZE_CONTINENT_LONG	80+1
+#define IPV6CALC_DB_SIZE_STATEPROV	80+1
+#define IPV6CALC_DB_SIZE_DISTRICT	80+1
+#define IPV6CALC_DB_SIZE_CITY		80+1
+#define IPV6CALC_DB_SIZE_ZIPCODE	20+1
+#define IPV6CALC_DB_SIZE_WEATHERSTATIONCODE	20+1
+#define IPV6CALC_DB_SIZE_WEATHERSTATIONNAME	80+1
+#define IPV6CALC_DB_SIZE_TIMEZONE_NAME	64+1
+#define IPV6CALC_DB_SIZE_ISP_NAME	128+1
+#define IPV6CALC_DB_SIZE_CONN_TYPE	20+1
+#define IPV6CALC_DB_SIZE_ORG_NAME	128+1
+#define IPV6CALC_DB_SIZE_DOMAIN		20+1
+#define IPV6CALC_DB_SIZE_DMA_CODE	8+1
+#define IPV6CALC_DB_SIZE_IDD_CODE	8+1
+#define IPV6CALC_DB_SIZE_AREA_CODE	8+1
+#define IPV6CALC_DB_SIZE_MOBILENETWORKCODE	80+1
+#define IPV6CALC_DB_SIZE_MOBILECOUNTRYCODE	8+1
+#define IPV6CALC_DB_SIZE_MOBILE_BRAND	80+1
+#define IPV6CALC_DB_SIZE_USAGE_TYPE	80+1
+
+#define IPV6CALC_DB_GEO_ELEVATION_UNKNOWN -20000
+#define IPV6CALC_DB_GEO_TIMEZONE_UNKNOWN  99
+#define IPV6CALC_DB_GEO_GEONAMEID_UNKNOWN  0
+
+// range: 0..7 (for anonymization)
+#define IPV6CALC_DB_GEO_GEONAMEID_TYPE_UNKNOWN    0
+#define IPV6CALC_DB_GEO_GEONAMEID_TYPE_CONTINENT  1
+#define IPV6CALC_DB_GEO_GEONAMEID_TYPE_COUNTRY    2
+#define IPV6CALC_DB_GEO_GEONAMEID_TYPE_STATEPROV  3
+#define IPV6CALC_DB_GEO_GEONAMEID_TYPE_DISTRICT   4
+#define IPV6CALC_DB_GEO_GEONAMEID_TYPE_CITY       5
+
+#define IPV6CALC_DB_GEO_GEONAMEID_TYPE_FLAG_24BIT	0x10000
+#define IPV6CALC_DB_GEO_GEONAMEID_TYPE_FLAG_MASK	0xf0000
+
+typedef struct
+{
+	char     country_code[IPV6CALC_DB_SIZE_COUNTRY_CODE];
+	char     country_long[IPV6CALC_DB_SIZE_COUNTRY_LONG];
+	char     continent_code[IPV6CALC_DB_SIZE_CONTINENT_CODE];
+	char     continent_long[IPV6CALC_DB_SIZE_CONTINENT_LONG];
+	char     stateprov[IPV6CALC_DB_SIZE_STATEPROV];
+	char     district[IPV6CALC_DB_SIZE_CITY];
+	char     city[IPV6CALC_DB_SIZE_CITY];
+	char     zipcode[IPV6CALC_DB_SIZE_ZIPCODE];
+	char     weatherstationcode[IPV6CALC_DB_SIZE_WEATHERSTATIONCODE];
+	char     weatherstationname[IPV6CALC_DB_SIZE_WEATHERSTATIONNAME];
+	char     dma_code[IPV6CALC_DB_SIZE_DMA_CODE];
+	char     idd_code[IPV6CALC_DB_SIZE_IDD_CODE];
+	char     area_code[IPV6CALC_DB_SIZE_AREA_CODE];
+	double   latitude;
+	double   longitude;
+	float    elevation;
+	uint16_t accuracy_radius;
+	uint32_t geoname_id;
+	uint32_t continent_geoname_id;
+	uint32_t country_geoname_id;
+	uint32_t stateprov_geoname_id;
+	uint32_t district_geoname_id;
+	uint32_t asn;
+	float    timezone_offset;
+	char     timezone_name[IPV6CALC_DB_SIZE_TIMEZONE_NAME];
+	char     isp_name[IPV6CALC_DB_SIZE_ISP_NAME];
+	char     connection_type[IPV6CALC_DB_SIZE_CONN_TYPE];
+	char     organization_name[IPV6CALC_DB_SIZE_ORG_NAME];
+	char     domain[IPV6CALC_DB_SIZE_DOMAIN];
+	char     mobile_network_code[IPV6CALC_DB_SIZE_MOBILENETWORKCODE];
+	char     mobile_country_code[IPV6CALC_DB_SIZE_MOBILECOUNTRYCODE];
+	char     mobile_brand[IPV6CALC_DB_SIZE_MOBILE_BRAND];
+	char     usage_type[IPV6CALC_DB_SIZE_USAGE_TYPE];
+} libipv6calc_db_wrapper_geolocation_record;
+
+static const s_data_sources geonameid_types[] = {
+	{ IPV6CALC_DB_GEO_GEONAMEID_TYPE_CONTINENT	, "Continent" , "Continent"  },
+	{ IPV6CALC_DB_GEO_GEONAMEID_TYPE_COUNTRY	, "Country"   , "Country"    },
+	{ IPV6CALC_DB_GEO_GEONAMEID_TYPE_STATEPROV	, "Region"    , "Region"     },
+	{ IPV6CALC_DB_GEO_GEONAMEID_TYPE_DISTRICT	, "District"  , "District"   },
+	{ IPV6CALC_DB_GEO_GEONAMEID_TYPE_CITY		, "City"      , "City"       },
+};
+
 // define internal API versions
 #define IPV6CALC_DB_API_GEOIP		1
 #define IPV6CALC_DB_API_IP2LOCATION	1
@@ -201,6 +307,7 @@ typedef struct {
 #define COUNTRYCODE_INDEX_LETTER_MAX     (COUNTRYCODE_LETTER1_MAX * COUNTRYCODE_LETTER2_MAX - 1)
 #define COUNTRYCODE_INDEX_MAX            1023	// 0x3ff
 #define COUNTRYCODE_INDEX_UNKNOWN        1022	// 0x3fe
+#define COUNTRYCODE_INDEX_LISP		 1021	// 0x3fd
 
 #define COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MAX   (COUNTRYCODE_INDEX_UNKNOWN - 1)
 #define COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MIN   (COUNTRYCODE_INDEX_UNKNOWN - 16)
@@ -261,6 +368,7 @@ extern void libipv6calc_db_wrapper_features(char *string, const size_t size);
 extern void libipv6calc_db_wrapper_capabilities(char *string, const size_t size);
 extern void libipv6calc_db_wrapper_features_help(void);
 extern void libipv6calc_db_wrapper_print_db_info(const int level_verbose, const char *prefix_string);
+extern void libipv6calc_db_wrapper_print_features_verbose(const int level_verbose);
 extern int  libipv6calc_db_wrapper_has_features(uint32_t features);
 extern int  libipv6calc_db_wrapper_options(const int opt, const char *optarg, const struct option longopts[]);
 extern const char *libipv6calc_db_wrapper_get_data_source_name_by_number(const unsigned int number);
@@ -274,13 +382,14 @@ extern int         libipv6calc_db_wrapper_country_code_by_cc_index(char *string,
 extern uint16_t    libipv6calc_db_wrapper_cc_index_by_addr(const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr);
 
 // Autonomous System Text/Number
-extern char       *libipv6calc_db_wrapper_as_text_by_addr(const ipv6calc_ipaddr *ipaddrp);
-extern uint32_t    libipv6calc_db_wrapper_as_num32_by_addr(const ipv6calc_ipaddr *ipaddrp);
-extern uint16_t    libipv6calc_db_wrapper_as_num16_by_addr(const ipv6calc_ipaddr *ipaddrp);
+extern uint32_t    libipv6calc_db_wrapper_as_num32_by_addr(const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr);
 
 extern uint32_t    libipv6calc_db_wrapper_as_num32_comp17(const uint32_t as_num32);
 extern uint32_t    libipv6calc_db_wrapper_as_num32_decomp17(const uint32_t as_num32_comp17);
 
+// GeonameID
+extern uint32_t    libipv6calc_db_wrapper_GeonameID_by_addr(const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr, unsigned int *GeonameID_type_ptr);
+
 // Registries
 extern int         libipv6calc_db_wrapper_registry_num_by_as_num32(const uint32_t as_num32);
 extern int         libipv6calc_db_wrapper_registry_num_by_cc_index(const uint16_t cc_index);
@@ -301,6 +410,8 @@ extern int libipv6calc_db_wrapper_registry_string_by_ipv6addr(const ipv6calc_ipv
 extern int libipv6calc_db_wrapper_registry_num_by_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp);
 extern int libipv6calc_db_wrapper_info_by_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp, char *string, const size_t string_len);
 
+// geolocation record
+extern void libipv6calc_db_wrapper_geolocation_record_clear(libipv6calc_db_wrapper_geolocation_record *recordp);
 
 #ifdef HAVE_BERKELEY_DB_SUPPORT
 extern int libipv6calc_db_wrapper_bdb_get_data_by_key(DB *dbp, char *token, char *value, const size_t value_size);
