@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_DBIP.h
- * Version    : $Id: dd146087d1b83a6be0bd278dd89657faa979ce14 $
- * Copyright  : 2014-2017 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: c08e00422ebee445269010281667e00d615f1c0f $
+ * Copyright  : 2014-2019 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc_db_wrapper_DBIP.c
@@ -117,35 +117,6 @@ typedef struct
         uint32_t ipversion;
 } DBIP;
 
-
-// from https://db-ip.com/db/
-#define DBIP_SIZE_COUNTRY	2+1
-#define DBIP_SIZE_STATEPROV	80+1
-#define DBIP_SIZE_DISTRICT	80+1
-#define DBIP_SIZE_CITY		80+1
-#define DBIP_SIZE_ZIPCODE	20+1
-#define DBIP_SIZE_TIMEZONE_NAME	64+1
-#define DBIP_SIZE_ISP_NAME	128+1
-#define DBIP_SIZE_CONN_TYPE	8+1
-#define DBIP_SIZE_ORG_NAME	128+1
-typedef struct
-{
-	char     country[DBIP_SIZE_COUNTRY];
-	char     stateprov[DBIP_SIZE_STATEPROV];
-	char     district[DBIP_SIZE_CITY];
-	char     city[DBIP_SIZE_CITY];
-	char     zipcode[DBIP_SIZE_ZIPCODE];
-	float    latitude;
-	float    longitude;
-	uint32_t geoname_id;
-	float    timezone_offset;
-	char     timezone_name[DBIP_SIZE_TIMEZONE_NAME];
-	char     isp_name[DBIP_SIZE_ISP_NAME];
-	char     connection_type[DBIP_SIZE_CONN_TYPE];
-	char     organization_name[DBIP_SIZE_ORG_NAME];
-} DBIP_Record;
-
-
 #endif
 
 extern int         libipv6calc_db_wrapper_DBIP_wrapper_init(void);
@@ -155,7 +126,6 @@ extern void        libipv6calc_db_wrapper_DBIP_wrapper_print_db_info(const int l
 extern char       *libipv6calc_db_wrapper_DBIP_wrapper_db_info_used(void);
 
 extern int         libipv6calc_db_wrapper_DBIP_wrapper_country_code_by_addr(const ipv6calc_ipaddr *ipaddrp, char *country, const size_t country_len);
-extern int	   libipv6calc_db_wrapper_DBIP_wrapper_city_by_addr(const ipv6calc_ipaddr *ipaddrp, char *city, const size_t city_len, char *region, const size_t region_len); 
 
 extern int         libipv6calc_db_wrapper_DBIP_has_features(const uint32_t features);
 
@@ -175,6 +145,6 @@ extern char        *libipv6calc_db_wrapper_DBIP_database_info(const unsigned int
 extern int dbip_db_comm_to_free_switch_min_delta_months;
 extern int dbip_db_only_type;
 
-extern int          libipv6calc_db_wrapper_DBIP_all_by_addr(const ipv6calc_ipaddr *ipaddrp, DBIP_Record *recordp);
+extern int          libipv6calc_db_wrapper_DBIP_all_by_addr(const ipv6calc_ipaddr *ipaddrp, libipv6calc_db_wrapper_geolocation_record *recordp);
 
 #endif
