@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_GeoIP.h
- * Version    : $Id: 586dd235b8dc97c3a691abb0cd4cfc15a0eea0de $
- * Copyright  : 2013-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 3330195e8d11c4c68b21e9cc22ab76928dfb190b $
+ * Copyright  : 2013-2019 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc_db_wrapper_GeoIP.c
@@ -35,8 +35,8 @@ extern uint32_t lib_features_GeoIP;
 extern int          libipv6calc_db_wrapper_GeoIP_wrapper_init(void);
 extern int          libipv6calc_db_wrapper_GeoIP_wrapper_cleanup(void);
 extern const char  *libipv6calc_db_wrapper_GeoIP_wrapper_country_code_by_addr(const char *addr, const int proto);
-extern const char  *libipv6calc_db_wrapper_GeoIP_wrapper_country_name_by_addr(const char *addr, const int proto);
 extern char        *libipv6calc_db_wrapper_GeoIP_wrapper_asnum_by_addr(const char *addr, const int proto);
+extern uint32_t     libipv6calc_db_wrapper_GeoIP_wrapper_asn_by_addr(const ipv6calc_ipaddr *ipaddrp);
 extern void         libipv6calc_db_wrapper_GeoIP_wrapper_info(char* string, const size_t size);
 extern void         libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose, const char *prefix_string);
 extern char        *libipv6calc_db_wrapper_GeoIP_wrapper_db_info_used(void);
@@ -75,5 +75,5 @@ extern void          libipv6calc_db_wrapper_GeoIP_setup_custom_directory(char *d
 extern const char  **libipv6calc_db_wrapper_GeoIPDBDescription;
 extern char       ***libipv6calc_db_wrapper_GeoIPDBFileName_ptr;
 
-extern GeoIPRecord *libipv6calc_db_wrapper_GeoIP_wrapper_record_city_by_addr(const char *addr, const int proto);
+extern int          libipv6calc_db_wrapper_GeoIP_all_by_addr(const ipv6calc_ipaddr *ipaddrp, libipv6calc_db_wrapper_geolocation_record *recordp);
 #endif
