@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc/ipv6calc.c
- * Version    : $Id: 2eb8ebcd4bae67ccfbd0cb10edab2d7e4ebc6cc7 $
- * Copyright  : 2001-2017 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 326939d66c69589c5f2d78f3bcaced782975dbad $
+ * Copyright  : 2001-2019 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Central program (main)
@@ -79,6 +79,7 @@ s_ipv6calc_anon_set ipv6calc_anon_set;
 int feature_zeroize = 1; // always supported
 int feature_anon    = 1; // always supported
 int feature_kp      = 0; // will be checked later
+int feature_kg      = 0; // will be checked later
 
 /* showinfo machine readable filter */
 char showinfo_machine_readable_filter[32] = "";
@@ -104,6 +105,7 @@ int main(int argc, char *argv[]) {
 	char *input1 = NULL, *input2 = NULL;
 	int inputc;
 	int inputtype_given = 0, outputtype_given = 0, action_given = 0;
+	uint16_t cc_index;
 
 	int ipv6rd_prefixlength = -1;
 
@@ -307,12 +309,14 @@ int main(int argc, char *argv[]) {
 				if (inputtype != FORMAT_undefined || outputtype != FORMAT_undefined) { printhelp_doublecommands(); exit(EXIT_FAILURE); };
 				inputtype  = FORMAT_ipv6addr;
 				outputtype = FORMAT_bitstring;
+				outputtype_given = 1;
 				break;
 				
 			case CMD_addr_to_compressed:
 				if (inputtype != FORMAT_undefined || outputtype != FORMAT_undefined) { printhelp_doublecommands(); exit(EXIT_FAILURE); };
 				inputtype  = FORMAT_ipv6addr;
 				outputtype = FORMAT_ipv6addr;
+				outputtype_given = 1;
 				formatoptions |= FORMATOPTION_printcompressed;
 				break;
 				
@@ -320,6 +324,7 @@ int main(int argc, char *argv[]) {
 				if (inputtype != FORMAT_undefined || outputtype != FORMAT_undefined) { printhelp_doublecommands(); exit(EXIT_FAILURE); };
 				inputtype  = FORMAT_ipv6addr;
 				outputtype = FORMAT_ipv6addr;
+				outputtype_given = 1;
 				formatoptions |= FORMATOPTION_printuncompressed;
 				break;
 				
@@ -327,12 +332,14 @@ int main(int argc, char *argv[]) {
 				if (inputtype != FORMAT_undefined || outputtype != FORMAT_undefined) { printhelp_doublecommands(); exit(EXIT_FAILURE); };
 				inputtype  = FORMAT_ipv6addr;
 				outputtype = FORMAT_base85;
+				outputtype_given = 1;
 				break;
 				
 			case CMD_base85_to_addr:
 				if (inputtype != FORMAT_undefined || outputtype != FORMAT_undefined) { printhelp_doublecommands(); exit(EXIT_FAILURE); };
 				inputtype  = FORMAT_base85;
 				outputtype = FORMAT_ipv6addr;
+				outputtype_given = 1;
 				formatoptions |= FORMATOPTION_printuncompressed;
 				break;
 
@@ -340,6 +347,7 @@ int main(int argc, char *argv[]) {
 				if (inputtype != FORMAT_undefined || outputtype != FORMAT_undefined) { printhelp_doublecommands(); exit(EXIT_FAILURE); };
 				inputtype  = FORMAT_mac;
 				outputtype = FORMAT_eui64;
+				outputtype_given = 1;
 				action = ACTION_mac_to_eui64;
 				break;
 				
@@ -347,6 +355,7 @@ int main(int argc, char *argv[]) {
 				if (inputtype != FORMAT_undefined || outputtype != FORMAT_undefined) { printhelp_doublecommands(); exit(EXIT_FAILURE); };
 				inputtype  = FORMAT_ipv6addr;
 				outputtype = FORMAT_ipv6addr;
+				outputtype_given = 1;
 				formatoptions |= FORMATOPTION_printfulluncompressed;
 				break;
 				
@@ -354,12 +363,14 @@ int main(int argc, char *argv[]) {
 				if (inputtype != FORMAT_undefined || outputtype != FORMAT_undefined) { printhelp_doublecommands(); exit(EXIT_FAILURE); };
 				inputtype  = FORMAT_ipv6addr;
 				outputtype = FORMAT_ifinet6;
+				outputtype_given = 1;
 				break;
 
 			case CMD_ifinet6_to_compressed:
 				if (inputtype != FORMAT_undefined || outputtype != FORMAT_undefined) { printhelp_doublecommands(); exit(EXIT_FAILURE); };
 				inputtype = FORMAT_ifinet6;
 				outputtype = FORMAT_ipv6addr;
+				outputtype_given = 1;
 				formatoptions |= FORMATOPTION_printcompressed;
 				break;
 				
@@ -377,6 +388,12 @@ int main(int argc, char *argv[]) {
 				action = ACTION_iid_token_to_privacy;
 				break;
 
+			case CMD_addr_to_countrycode:
+				inputtype = FORMAT_auto;
+				outputtype = FORMAT_auto_noresult;
+				action = ACTION_addr_to_countrycode;
+				break;
+
 			case 'i':
 			case CMD_showinfo:
 				command = CMD_showinfo;
@@ -399,7 +416,7 @@ int main(int argc, char *argv[]) {
 				if ((atoi(optarg) >= 1) && (atoi(optarg) <= 32)) {
 					ipv6rd_prefixlength = atoi(optarg);
 				} else {
-					fprintf(stderr, " Argument of option '6rd_prefixlength' is out or range (1-32): %d\n", atoi(optarg));
+					fprintf(stderr, " Argument of option '6rd_prefixlength' is out of range (1-32): %d\n", atoi(optarg));
 					exit(EXIT_FAILURE);
 				};
 				break;
@@ -517,7 +534,7 @@ int main(int argc, char *argv[]) {
 					force_prefix = atoi(optarg);
 					formatoptions |= FORMATOPTION_forceprefix;
 				} else {
-					fprintf(stderr, " Argument of option 'forceprefix' is out or range (1-128): %d\n", atoi(optarg));
+					fprintf(stderr, " Argument of option 'forceprefix' is out of range (1-128): %d\n", atoi(optarg));
 					exit(EXIT_FAILURE);
 				};
 				break;
@@ -528,7 +545,7 @@ int main(int argc, char *argv[]) {
 					bit_start = atoi(optarg);
 					formatoptions |= FORMATOPTION_printstart;
 				} else {
-					fprintf(stderr, " Argument of option 'printstart' is out or range (1-128): %d\n", atoi(optarg));
+					fprintf(stderr, " Argument of option 'printstart' is out of range (1-128): %d\n", atoi(optarg));
 					exit(EXIT_FAILURE);
 				};
 				break;
@@ -539,7 +556,7 @@ int main(int argc, char *argv[]) {
 					bit_end = atoi(optarg);
 					formatoptions |= FORMATOPTION_printend;
 				} else {
-					fprintf(stderr, " Argument of option 'printend' is out or range (1-128): %d\n", atoi(optarg));
+					fprintf(stderr, " Argument of option 'printend' is out of range (1-128): %d\n", atoi(optarg));
 					exit(EXIT_FAILURE);
 				};
 				break;
@@ -588,6 +605,14 @@ int main(int argc, char *argv[]) {
 				formatoptions |= (FORMATOPTION_mr_match_token | FORMATOPTION_machinereadable);
 				break;
 
+			case FORMATOPTION_NUM_mr_match_token_suffix + FORMATOPTION_NUM_HEAD:
+				if (strlen(showinfo_machine_readable_filter) >= sizeof(showinfo_machine_readable_filter)) {
+					fprintf(stderr, " Argument of option 'mrmts' is too long: %s\n", optarg);
+					exit(EXIT_FAILURE);
+				};
+				snprintf(showinfo_machine_readable_filter, sizeof(showinfo_machine_readable_filter), "%s", optarg);
+				formatoptions |= (FORMATOPTION_mr_match_token_suffix | FORMATOPTION_machinereadable);
+				break;
 
 			case 'm':	
 			case FORMATOPTION_NUM_machinereadable + FORMATOPTION_NUM_HEAD:
@@ -683,14 +708,17 @@ int main(int argc, char *argv[]) {
 				break;
 				
 			default:
+				fprintf(stderr, "Unsupported option: %s\n", argv[optind - 1]);
 				fprintf(stderr, "Usage: (see '%s --command -?|-h|--help' for more help)\n", PROGRAM_NAME);
-				ipv6calc_printhelp(longopts, ipv6calc_longopts_shortopts_map);
+				// ipv6calc_printhelp(longopts, ipv6calc_longopts_shortopts_map);
 				exit(EXIT_FAILURE);
 		};
 	};
 	argv += optind;
 	argc -= optind;
 
+	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "End of option local parsing: argc=%d", argc);
+
 	if (ipv6calc_quiet != 0) {
 		formatoptions |= FORMATOPTION_quiet;
 	};
@@ -698,6 +726,7 @@ int main(int argc, char *argv[]) {
 	/* initialise database wrapper */
 	result = libipv6calc_db_wrapper_init("");
 	if (result != 0) {
+		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "db_wrapper_init failed, result=%d", result);
 		exit(EXIT_FAILURE);
 	};
 
@@ -707,6 +736,12 @@ int main(int argc, char *argv[]) {
 		feature_kp = 1;
 	};
 
+	/* check for KeepTypeGeonameID support */
+	if ((libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEGEONAMEID_IPV4_REQ_DB) == 1) \
+	    && (libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEGEONAMEID_IPV6_REQ_DB) == 1)) {
+		feature_kg = 1;
+	};
+
 	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Debug value:%08lx command:%08lx inputtype:%08lx outputtype:%08lx action:%08lx formatoptions:%08lx", (unsigned long) ipv6calc_debug, (unsigned long) command, (unsigned long) inputtype, (unsigned long) outputtype, (unsigned long) action, (unsigned long) formatoptions); // ipv6calc_debug usage ok
 
 	/* do work depending on selection */
@@ -731,25 +766,31 @@ int main(int argc, char *argv[]) {
 
 	if (command & CMD_printhelp) {
 		if ( (outputtype == FORMAT_undefined) && (inputtype == FORMAT_undefined) && (action == ACTION_undefined)) {
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "printhelp/longopts");
 			ipv6calc_printhelp(longopts, ipv6calc_longopts_shortopts_map);
 			exit(EXIT_FAILURE);
 		} else if (outputtype == FORMAT_auto) {
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "printhelp_outputtypes");
 			if (inputtype == FORMAT_undefined) {
 				inputtype = FORMAT_auto;
 			};
 			printhelp_outputtypes(inputtype, formatoptions);
 			exit(EXIT_FAILURE);
-		} else if (inputtype == FORMAT_auto) {
+		} else if ((inputtype == FORMAT_auto) && (outputtype != FORMAT_auto_noresult)) {
 			if (outputtype == FORMAT_undefined) {
+				DEBUGPRINT_NA(DEBUG_ipv6calc_general, "printhelp_inputtypes");
 				printhelp_inputtypes(formatoptions);
 			} else {
+				DEBUGPRINT_NA(DEBUG_ipv6calc_general, "printhelp_output_dispatcher");
 				printhelp_output_dispatcher(outputtype);
 			};
 			exit(EXIT_FAILURE);
 		} else if (action == ACTION_auto) {
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "printhelp_actiontypes");
 			printhelp_actiontypes(formatoptions, ipv6calc_longopts);
 			exit(EXIT_FAILURE);
 		} else if (action != ACTION_undefined) {
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "printhelp_action_dispatcher");
 			printhelp_action_dispatcher(action, 0);
 			exit(EXIT_FAILURE);
 		};
@@ -884,7 +925,7 @@ PIPE_input:
 		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Token 1: '%s'", input1);
 
 		/* check for second token */
-		if (*ptrptr[0] != '\0') {
+		if (ptrptr && ptrptr[0] && *ptrptr[0] != '\0') {
 			input2 = *ptrptr;
 			inputc = 2;
 
@@ -902,7 +943,7 @@ PIPE_input:
 	};
 	
 	/* reset input type in case of action=filter and pipe mode */
-	if ((input_is_pipe == 1) && (action_given == 1) && ( (action == ACTION_filter) || (action == ACTION_test) ) ) {
+	if ((input_is_pipe == 1) && (action_given == 1) && ( (action == ACTION_filter) || (action == ACTION_test) || (action == ACTION_addr_to_countrycode)) ) {
 		DEBUGPRINT_NA(DEBUG_ipv6calc_general, "reset input type for later autodetection");
 		inputtype = FORMAT_auto;
 
@@ -961,7 +1002,13 @@ PIPE_input:
 			if ( outputtype == FORMAT_undefined ) {
 				outputtype = FORMAT_ipv6addr;
 			};
+		} else if ( (inputtype == FORMAT_ipv6addr && (input_is_pipe == 0 || inputtype_given == 1)) && (outputtype == FORMAT_mac && outputtype_given == 1) ) {
+			action = ACTION_ipv6_to_mac;
+		} else if ( (inputtype == FORMAT_ipv6addr && (input_is_pipe == 0 || inputtype_given == 1)) && (outputtype == FORMAT_eui64 && outputtype_given == 1) ) {
+			action = ACTION_ipv6_to_eui64;
 		};
+	} else if (action == ACTION_addr_to_countrycode) {
+		outputtype = FORMAT_auto_noresult;
 	};
 
 	if (input_is_pipe == 0 && action_given == 0) {
@@ -1188,7 +1235,7 @@ PIPE_input:
 	};
 
 	if (ipv6addr.flag_valid == 1) {
-		ipv6addr_settype(&ipv6addr, 1); /* Set typeinfo */
+		ipv6addr_settype(&ipv6addr); /* Set typeinfo */
 
 		/* honor 6rd prefix length option */
 		if (ipv6rd_prefixlength > 0) {
@@ -1414,6 +1461,62 @@ PIPE_input:
 			};
 			break;
 
+		case ACTION_ipv6_to_eui64:
+			if (inputtype == FORMAT_ipv6addr && outputtype == FORMAT_eui64) {
+				/* IPv6 -> EUI64 extraction */
+				if (ipv6addr.flag_valid != 1) {
+					fprintf(stderr, "No valid IPv6 address given!\n");
+					exit(EXIT_FAILURE);
+				};
+
+				if ((ipv6addr.typeinfo & IPV6_NEW_ADDR_IID) == IPV6_NEW_ADDR_IID) {
+					DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Extract EUI-64 from IPv6 address");
+					eui64addr.addr[0] = ipv6addr_getoctet(&ipv6addr,  8) ^ 0x02;
+					eui64addr.addr[1] = ipv6addr_getoctet(&ipv6addr,  9);
+					eui64addr.addr[2] = ipv6addr_getoctet(&ipv6addr, 10);
+					eui64addr.addr[3] = ipv6addr_getoctet(&ipv6addr, 11);
+					eui64addr.addr[4] = ipv6addr_getoctet(&ipv6addr, 12);
+					eui64addr.addr[5] = ipv6addr_getoctet(&ipv6addr, 13);
+					eui64addr.addr[6] = ipv6addr_getoctet(&ipv6addr, 14);
+					eui64addr.addr[7] = ipv6addr_getoctet(&ipv6addr, 15);
+					eui64addr.flag_valid = 1;
+				} else {
+					fprintf(stderr, "IPv6 address is not containing EUI64 suffix!\n");
+					exit(EXIT_FAILURE);
+				};
+			} else {
+				fprintf(stderr, "Unsupported EUI64 extraction!\n");
+				exit(EXIT_FAILURE);
+			};
+			break;
+
+		case ACTION_ipv6_to_mac:
+			if (inputtype == FORMAT_ipv6addr && outputtype == FORMAT_mac) {
+				/* IPv6 -> MAC extraction */
+				if (ipv6addr.flag_valid != 1) {
+					fprintf(stderr, "No valid IPv6 address given!\n");
+					exit(EXIT_FAILURE);
+				};
+
+				if ((ipv6addr.typeinfo & IPV6_NEW_ADDR_IID_EUI48) == IPV6_NEW_ADDR_IID_EUI48) {
+					DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Extract MAC from IPv6 address");
+					macaddr.addr[0] = ipv6addr_getoctet(&ipv6addr,  8) ^ 0x02;
+					macaddr.addr[1] = ipv6addr_getoctet(&ipv6addr,  9);
+					macaddr.addr[2] = ipv6addr_getoctet(&ipv6addr, 10);
+					macaddr.addr[3] = ipv6addr_getoctet(&ipv6addr, 13);
+					macaddr.addr[4] = ipv6addr_getoctet(&ipv6addr, 14);
+					macaddr.addr[5] = ipv6addr_getoctet(&ipv6addr, 15);
+					macaddr.flag_valid = 1;
+				} else {
+					fprintf(stderr, "IPv6 address is not containing EUI64 suffix!\n");
+					exit(EXIT_FAILURE);
+				};
+			} else {
+				fprintf(stderr, "Unsupported EUI64 extraction!\n");
+				exit(EXIT_FAILURE);
+			};
+			break;
+
 		case ACTION_anonymize:
 			if ((inputtype == FORMAT_ipv4addr || inputtype == FORMAT_ipv4hex || inputtype == FORMAT_ipv4revhex) && outputtype == FORMAT_ipv4addr) {
 				/* anonymize IPv4 address */
@@ -1803,6 +1906,51 @@ PIPE_input:
 			goto RESULT_print;
 			break;
 
+		case ACTION_addr_to_countrycode:
+			cc_index = COUNTRYCODE_INDEX_MAX;
+
+			if (inputtype == FORMAT_ipv4addr || inputtype == FORMAT_ipv4hex || inputtype == FORMAT_ipv4revhex) {
+				/* retrieve country code of IPv4 address */
+				if (ipv4addr.flag_valid != 1) {
+					fprintf(stderr, "No valid IPv4 address given!\n");
+					exit(EXIT_FAILURE);
+				};
+				if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_CC) == 1) {
+					cc_index = libipv4addr_cc_index_by_addr(&ipv4addr, NULL);
+				};
+
+			} else if (inputtype == FORMAT_ipv6addr || inputtype == FORMAT_bitstring || inputtype == FORMAT_revnibbles_int || inputtype == FORMAT_revnibbles_arpa || inputtype == FORMAT_base85 || inputtype == FORMAT_ipv6literal) {
+				/* retrieve country code of IPv6 address */
+				if (ipv6addr.flag_valid != 1) {
+					fprintf(stderr, "No valid IPv6 address given!\n");
+					exit(EXIT_FAILURE);
+				};
+				if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV6_TO_CC) == 1) {
+					cc_index = libipv6addr_cc_index_by_addr(&ipv6addr, NULL);
+				};
+
+			} else {
+				fprintf(stderr, "Unsupported input type for 'addr2cc' (need to be IPv4/IPv6 address)!\n");
+				exit(EXIT_FAILURE);
+			};
+
+			if (cc_index == COUNTRYCODE_INDEX_UNKNOWN) {
+				snprintf(resultstring, sizeof(resultstring), "%s%s"
+				    , "--"
+				    , ((formatoptions & FORMATOPTION_quiet) == 0) ? " (unknown)": ""
+				);
+			} else if (cc_index == COUNTRYCODE_INDEX_MAX) {
+				snprintf(resultstring, sizeof(resultstring), "%s%s"
+				    , "--"
+				    , ((formatoptions & FORMATOPTION_quiet) == 0) ? " (no-usable-database)" : ""
+				);
+			} else {
+				snprintf(resultstring, sizeof(resultstring), "%c%c", COUNTRYCODE_INDEX_TO_CHAR1(cc_index), COUNTRYCODE_INDEX_TO_CHAR2(cc_index));
+			};
+			goto RESULT_print;
+
+			break;
+
 		case ACTION_undefined:
 			/* no action selected */
 			break;
@@ -1941,7 +2089,7 @@ PIPE_input:
 
 			if ((formatoptions & FORMATOPTION_print_iid_var) == FORMATOPTION_print_iid_var) {
 				iid_random_result = ipv6addr_iidrandomdetection(&ipv6addr, &iid_statistics);
-				sprintf(resultstring2, "%-40s R=%d h=%7.3f r=%7.3f db= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dbh= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d da= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dd= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dda= %d", resultstring, \
+				snprintf(resultstring2, sizeof(resultstring2), "%-40s R=%d h=%7.3f r=%7.3f db= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dbh= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d da= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dd= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dda= %d", resultstring, \
 					iid_random_result, iid_statistics.hexdigit, iid_statistics.lls_residual, \
 					iid_statistics.digit_blocks[0], iid_statistics.digit_blocks[1], iid_statistics.digit_blocks[2], iid_statistics.digit_blocks[3], iid_statistics.digit_blocks[4], iid_statistics.digit_blocks[5], iid_statistics.digit_blocks[6], iid_statistics.digit_blocks[7], iid_statistics.digit_blocks[8], iid_statistics.digit_blocks[9], iid_statistics.digit_blocks[10], iid_statistics.digit_blocks[11], iid_statistics.digit_blocks[12], iid_statistics.digit_blocks[13], iid_statistics.digit_blocks[14], iid_statistics.digit_blocks[15], \
 					iid_statistics.digit_blocks_hexdigit[0], iid_statistics.digit_blocks_hexdigit[1], iid_statistics.digit_blocks_hexdigit[2], iid_statistics.digit_blocks_hexdigit[3], iid_statistics.digit_blocks_hexdigit[4], iid_statistics.digit_blocks_hexdigit[5], iid_statistics.digit_blocks_hexdigit[6], iid_statistics.digit_blocks_hexdigit[7], iid_statistics.digit_blocks_hexdigit[8], iid_statistics.digit_blocks_hexdigit[9], iid_statistics.digit_blocks_hexdigit[10], iid_statistics.digit_blocks_hexdigit[11], iid_statistics.digit_blocks_hexdigit[12], iid_statistics.digit_blocks_hexdigit[13], iid_statistics.digit_blocks_hexdigit[14], iid_statistics.digit_blocks_hexdigit[15], \
@@ -1950,7 +2098,7 @@ PIPE_input:
 					iid_statistics.digit_delta[16], iid_statistics.digit_delta[17], iid_statistics.digit_delta[18], iid_statistics.digit_delta[19], iid_statistics.digit_delta[20], iid_statistics.digit_delta[21], iid_statistics.digit_delta[22], iid_statistics.digit_delta[23], iid_statistics.digit_delta[24], iid_statistics.digit_delta[25], iid_statistics.digit_delta[26], iid_statistics.digit_delta[27], iid_statistics.digit_delta[28], iid_statistics.digit_delta[29], iid_statistics.digit_delta[30], \
 					iid_statistics.digit_delta_amount
 				);
-				sprintf(resultstring, "%s", resultstring2);
+				snprintf(resultstring, sizeof(resultstring), "%s", resultstring2);
 			};
 			break;
 
@@ -1979,7 +2127,7 @@ PIPE_input:
 				if (ipv6addr.prefixlength != 64) { fprintf(stderr, "No valid EUI-64 identifier given!\n"); exit(EXIT_FAILURE); };
 				formatoptions |= FORMATOPTION_printsuffix;
 				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, sizeof(resultstring), formatoptions);
-			} else if (action == ACTION_anonymize) {
+			} else if ((action == ACTION_anonymize) || (action == ACTION_ipv6_to_eui64)) {
 				retval = libeui64_eui64addrstruct_to_string(&eui64addr, resultstring, sizeof(resultstring), formatoptions);
 			} else {
 				fprintf(stderr, "Specify proper action or input for output format: eui64\n"); exit(EXIT_FAILURE);
