@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6calc.sh
-# Version    : $Id: 2b49d0565960d19f78b2627ea9ff52336077f198 $
+# Version    : $Id: 0591b1b652b78be3e17845c8ae7fe7dafd709503 $
 # Copyright  : 2001-2015 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc conversions
@@ -227,6 +227,14 @@ NOPIPETEST--out eui64 00:0:F:6:4:5					=200:fff:fe06:405
 -O hex --forceprefix 24 --printsuffix 1.2.3.4					=04
 -O hex --forceprefix 24 --printprefix 1.2.3.4					=010203
 -O hex -u 192.168.1.1								=C0A80101
+# Extraction
+NOPIPETEST--in ipv6 2001:db8::a8bb:ccff:fedd:eeff --out eui64                             =aa:bb:cc:ff:fe:dd:ee:ff
+NOPIPETEST--in ipv6 2001:db8::a8bb:ccff:fedd:eeff --out mac                               =aa:bb:cc:dd:ee:ff
+# Countrycode
+NOPIPETEST-A addr2cc 3ffe:831f:ce49:7601:8000:efff:af4a:86bf			=IT;DB_IPV6_CC
+NOPIPETEST-A addr2cc 8.8.8.8							=US;DB_IPV4_CC
+NOPIPETEST--addr2cc 3ffe:831f:ce49:7601:8000:efff:af4a:86bf			=IT;DB_IPV6_CC
+NOPIPETEST--addr2cc 8.8.8.8							=US;DB_IPV4_CC
 END
 }
 
@@ -358,15 +366,28 @@ testscenarios | sed 's/NOPIPETEST//' | while read line; do
 	# extract result
 	command="`echo $line | awk -F= '{ print $1 }' | sed 's/ $//g'`"
 	result="`echo $line | awk -F= '{ for (i=2; i <= NF; i++) printf "%s%s", $i, (i<NF) ? "=" : ""; }'`"
+	# split condition
+	condition=`echo "$result" | awk -F';' '{ print $2 }'`
+	result=`echo "$result" | awk -F';' '{ print $1 }'`
 	if [ -z "$result" -o -z "$command" ]; then
 		echo "Something is wrong in line '$line'"
 		exit 1
 	fi
 
 	info="INFO  : test './ipv6calc $command' for '$result'"
+	[ -n "$condition" ] && info="$info (condition=$condition)"
 	[ "$verbose" = "1" ] && echo "$info"
 
-	#continue
+	# check condition
+	if [ -n "$condition" ]; then
+		if ./ipv6calc -v 2>&1 | grep -qw "$condition"; then
+			true
+		else
+			echo "NOTICE: condition not satisfied ($condition): ./ipv6calc $command"
+			continue
+		fi
+	fi
+
 	# get result
 	output="`./ipv6calc -q $command`"
 	retval=$?
