@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : test_scenarios.sh
-# Version    : $Id: bc24262d4c239d03597fa161bcc86fab08180ee1 $
+# Version    : $Id: 3cd87b9a1f8a5d950f58d05629f21b0cd29d0108 $
 # Copyright  : 2001-2017 by Peter Bieringer <pb (at) bieringer.de>
 # License    : GPLv2
 #
@@ -183,6 +183,7 @@ fe80::5e01:2345:6789				iid
 fe80::5e01:2345:6789				iid-local
 fe80::5e01:2345:6789				iid-isatap
 2001:1a:392e:a450:2cd3:75e1:6098:8104		orchid
+2001:2a:392e:a450:2cd3:75e1:6098:8104		orchid
 2001:1a:392e:a450:2cd3:75e1:6098:8104		^iid-local
 2001:1a:392e:a450:2cd3:75e1:6098:8104		^iid
 2001:1a:392e:a450:2cd3:75e1:6098:8104		^iid-random
@@ -431,9 +432,9 @@ a909:16fa:9092:23ff:a909:4941::7	IPV6_REGISTRY=RIPENCC
 1.2.3.4					IPV4=1.2.3.4|--mrst IPV4
 1.2.3.4					IPV4="1.2.3.4"|--mrst IPV4 --mrqva
 2a01:238:423d:8800:85b3:9e6b:3019:8909	IPV4=""|--mrstpa IPV4 --mrqva
-2a01:238:423d:8800:85b3:9e6b:3019:8909	"unicast,global-unicast,productive,iid-random,iid,iid-local"|--mrqva --mrtvo IPV6_TYPE
-2a01:238:423d:8800:85b3:9e6b:3019:8909	unicast,global-unicast,productive,iid-random,iid,iid-local|--mrqvn --mrtvo IPV6_TYPE
-2a01:238:423d:8800:85b3:9e6b:3019:8909	IPV6_TYPE=unicast,global-unicast,productive,iid-random,iid,iid-local|--mrst IPV6_TYPE
+2a01:238:423d:8800:85b3:9e6b:3019:8909	"ipv6,unicast,global-unicast,productive,iid-random,iid,iid-local"|--mrqva --mrtvo IPV6_TYPE
+2a01:238:423d:8800:85b3:9e6b:3019:8909	ipv6,unicast,global-unicast,productive,iid-random,iid,iid-local|--mrqvn --mrtvo IPV6_TYPE
+2a01:238:423d:8800:85b3:9e6b:3019:8909	IPV6_TYPE=ipv6,unicast,global-unicast,productive,iid-random,iid,iid-local|--mrst IPV6_TYPE
 # 6rd
 2001:b4c:0:2010::/60			IPV4[192.0.2.1]=192.0.2.1|--6rd_prefixlength 28
 2001:b4e:0:1008::/61			IPV4[192.0.2.1]=192.0.2.1|--6rd_prefixlength 29
@@ -506,8 +507,8 @@ testscenarios_showinfo_anonymized_info() {
 # IPv4 address
 2.2.3.4;;match;IPV4_ANON=253.134.12.143
 2.2.3.4;;key-word;IPV6CALC_FEATURES=ANON_KEEP-TYPE-ASN-CC
-2.2.3.4;--db-geoip-disable --db-ip2location-disable;match;IPV4_ANON=2.2.3.0
-2.2.3.4;--db-geoip-disable --db-ip2location-disable;key-no-word;IPV6CALC_FEATURES=ANON_KEEP-TYPE-ASN-CC
+2.2.3.4;--db-geoip-disable --db-ip2location-disable --db-geoip2-disable --db-dbip-disable --db-dbip2-disable;match;IPV4_ANON=2.2.3.0
+2.2.3.4;--db-geoip-disable --db-ip2location-disable --db-geoip2-disable --db-dbip-disable --db-dbip2-disable;key-no-word;IPV6CALC_FEATURES=ANON_KEEP-TYPE-ASN-CC
 END
 }
 
