@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6loganon.c
- * Version    : $Id: ad0cb3ded29cf5c7ed33ffe4a0634cf8fa3ce5cc $
+ * Version    : $Id: 1579820ea06a7f0dfa78b04b1b4d18e7dddd6f48 $
  * Copyright  : 2007-2017 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
@@ -57,6 +57,7 @@ int mask_mac;
 int feature_zeroize = 1; // always supported
 int feature_anon    = 1; // always supported
 int feature_kp      = 0; // will be checked later
+int feature_kg      = 0; // will be checked later
 
 
 /* prototypes */
@@ -230,6 +231,12 @@ int main(int argc,char *argv[]) {
 		feature_kp = 1;
 	};
 
+	/* check for KeepTypeGeonameID support */
+	if ((libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEGEONAMEID_IPV4_REQ_DB) == 1) \
+	    && (libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEGEONAMEID_IPV6_REQ_DB) == 1)) {
+		feature_kg = 1;
+	};
+
 	/* do work depending on selection */
 	DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "command=0x%08x", command);
 
