@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calccommands.h
- * Version    : $Id: bd22acf972eec0b0b995bb96cfc7ee9396c36e4c $
- * Copyright  : 2002-2017 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 0c21603ddce56cfcc3de830f577bdf396197d7fd $
+ * Copyright  : 2002-2019 by Peter Bieringer <pb (at) bieringer.de>
  * License    : GPLv2
  *
  * Information:
@@ -47,7 +47,8 @@
 #define CMD_mac_to_eui64		0x00010b0
 #define CMD_eui64_to_privacy		0x00010c0
 #define CMD_ifinet6_to_compressed	0x00010d0
-#define CMD_shortcut_end		0x00010d0
+#define CMD_addr_to_countrycode		0x00010e0
+#define CMD_shortcut_end		0x00010e0
 
 #define CMD_showinfo			0x0010010
 #define CMD_showinfotypes		0x0010020
@@ -85,6 +86,17 @@
 
 #define DB_builtin_disable		0x0024000
 
+#define DB_mmdb_disable			0x0025000
+#define DB_mmdb_lib			0x0025060
+
+#define DB_geoip2_disable		0x0026000
+#define DB_geoip2_dir			0x0026050
+
+#define DB_dbip2_disable		0x0027000
+#define DB_dbip2_dir			0x0027050
+#define DB_dbip2_comm_to_free_switch_min_delta_months		0x0027110
+#define DB_dbip2_only_type		0x0027120
+
 #define DB_common_priorization		0x002fff0
 
 
@@ -113,4 +125,7 @@
 #define CMD_test_lt			0x0050040	// less than
 #define CMD_test_le			0x0050050	// less equal
 
+/* no operations (dummy) */
+#define OPTION_NOOP			0xfffffff
+
 #endif
