@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calcoptions.c
- * Version    : $Id: b141178519e764a5dbca4bbc11b69a75a201ea2b $
- * Copyright  : 2013-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ea7f547e271c968576c3218ffa8cecb522d7b417 $
+ * Copyright  : 2013-2019 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  supporting common options
@@ -145,6 +145,11 @@ void ipv6calc_options_add_common_basic(char *shortopts_p, const int shortopts_ma
 
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_common, ipv6calc_longopts_common, MAXENTRIES_ARRAY(ipv6calc_longopts_common));
 
+#ifdef SUPPORT_MMDB
+	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "SUPPORT_MMDB");
+	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_mmdb, ipv6calc_longopts_mmdb, MAXENTRIES_ARRAY(ipv6calc_longopts_mmdb));
+#endif
+
 #ifdef SUPPORT_IP2LOCATION
 	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "SUPPORT_IP2LOCATION");
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_ip2location, ipv6calc_longopts_ip2location, MAXENTRIES_ARRAY(ipv6calc_longopts_ip2location));
@@ -155,11 +160,21 @@ void ipv6calc_options_add_common_basic(char *shortopts_p, const int shortopts_ma
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_geoip, ipv6calc_longopts_geoip, MAXENTRIES_ARRAY(ipv6calc_longopts_geoip));
 #endif
 
+#ifdef SUPPORT_GEOIP2
+	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "SUPPORT_GEOIP2");
+	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_geoip2, ipv6calc_longopts_geoip2, MAXENTRIES_ARRAY(ipv6calc_longopts_geoip2));
+#endif
+
 #ifdef SUPPORT_DBIP
 	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "SUPPORT_DBIP");
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_dbip, ipv6calc_longopts_dbip, MAXENTRIES_ARRAY(ipv6calc_longopts_dbip));
 #endif
 
+#ifdef SUPPORT_DBIP2
+	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "SUPPORT_DBIP2");
+	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_dbip2, ipv6calc_longopts_dbip2, MAXENTRIES_ARRAY(ipv6calc_longopts_dbip2));
+#endif
+
 #ifdef SUPPORT_EXTERNAL
 	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "SUPPORT_EXTERNAL");
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_external, ipv6calc_longopts_external, MAXENTRIES_ARRAY(ipv6calc_longopts_external));
@@ -170,7 +185,7 @@ void ipv6calc_options_add_common_basic(char *shortopts_p, const int shortopts_ma
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_builtin, ipv6calc_longopts_builtin, MAXENTRIES_ARRAY(ipv6calc_longopts_builtin));
 #endif
 
-#if defined SUPPORT_EXTERNAL || defined SUPPORT_DBIP || defined SUPPORT_GEOIP || SUPPORT_IP2LOCATION
+#if defined SUPPORT_EXTERNAL || defined SUPPORT_DBIP || defined SUPPORT_GEOIP || SUPPORT_IP2LOCATION || defined SUPPORT_DBIP2 || defined SUPPORT_GEOIP2
 	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "DB_COMMON");
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_db_common, ipv6calc_longopts_db_common, MAXENTRIES_ARRAY(ipv6calc_longopts_db_common));
 #endif
@@ -202,6 +217,11 @@ int ipv6calcoptions_common_basic(const int opt, const char *optarg, const struct
 
 	/* general options */
 	switch(opt) {
+		case OPTION_NOOP:
+			DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "Found dummy option, skip");
+			result = 0;
+			break;
+
 		case 'd':
 			DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Found debug option with value: %s", optarg);
 			ipv6calc_debug = parse_dec_hex_val(optarg);
@@ -214,12 +234,14 @@ int ipv6calcoptions_common_basic(const int opt, const char *optarg, const struct
 			ipv6calc_quiet = 1;
 			result = 0;
 			break;
+
 		case 'V':
 			DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "Found verbose option");
 			ipv6calc_verbose++;
 			ipv6calc_quiet = 0;
 			result = 0;
 			break;
+
 		default:
 			/* jump to other parsers */
 			DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Call sub-parser for opt=0x%08x", opt);
