@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calctypes.h
- * Version    : $Id: 517ca7a4cbd8b456ff0e15ee831863f9ea4bb4ca $
- * Copyright  : 2002-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: a74984cf7e1a7d3aac65c67f15c64901031394bb $
+ * Copyright  : 2002-2019 by Peter Bieringer <pb (at) bieringer.de>
  * License    : GPLv2
  *
  * Information:
@@ -183,6 +183,7 @@ typedef struct {
 #define FORMATOPTION_NUM_mr_select_token_pa	23	// 00800000
 #define FORMATOPTION_NUM_mr_match_token		24	// 01000000
 #define FORMATOPTION_NUM_mr_quote_default	25	// 02000000 flag for controlling old quote behavior < 0.99.0
+#define FORMATOPTION_NUM_mr_match_token_suffix	26	// 04000000
 
 #define FORMATOPTION_NUM_printembedded		31	// special
 
@@ -211,6 +212,7 @@ typedef struct {
 #define FORMATOPTION_mr_select_token_pa		(uint32_t) (1 << FORMATOPTION_NUM_mr_select_token_pa)
 #define FORMATOPTION_mr_match_token		(uint32_t) (1 << FORMATOPTION_NUM_mr_match_token)
 #define FORMATOPTION_mr_quote_default		(uint32_t) (1 << FORMATOPTION_NUM_mr_quote_default) // flag for controlling old quote behavior < 0.99.0
+#define FORMATOPTION_mr_match_token_suffix	(uint32_t) (1 << FORMATOPTION_NUM_mr_match_token_suffix)
 
 #define FORMATOPTION_printembedded		(uint32_t) (1 << FORMATOPTION_NUM_printembedded)
 
@@ -270,8 +272,11 @@ typedef struct {
 #define ACTION_NUM_6rd_local_prefix	6
 #define ACTION_NUM_6rd_extract_ipv4	7
 #define ACTION_NUM_ipv4_to_nat64	8
+#define ACTION_NUM_ipv6_to_mac		9
+#define ACTION_NUM_ipv6_to_eui64	10
 #define ACTION_NUM_filter		15
 #define ACTION_NUM_test			16
+#define ACTION_NUM_addr_to_countrycode	17
 #define ACTION_NUM_undefined		31
 
 #define ACTION_auto			(uint32_t) 0x0
@@ -283,13 +288,17 @@ typedef struct {
 #define ACTION_6rd_local_prefix		(uint32_t) (1 << ACTION_NUM_6rd_local_prefix)
 #define ACTION_6rd_extract_ipv4		(uint32_t) (1 << ACTION_NUM_6rd_extract_ipv4)
 #define ACTION_ipv4_to_nat64		(uint32_t) (1 << ACTION_NUM_ipv4_to_nat64)
+#define ACTION_ipv6_to_mac		(uint32_t) (1 << ACTION_NUM_ipv6_to_mac)
+#define ACTION_ipv6_to_eui64		(uint32_t) (1 << ACTION_NUM_ipv6_to_eui64)
 #define ACTION_filter			(uint32_t) (1 << ACTION_NUM_filter)
 #define ACTION_test			(uint32_t) (1 << ACTION_NUM_test)
+#define ACTION_addr_to_countrycode	(uint32_t) (1 << ACTION_NUM_addr_to_countrycode)
 #define ACTION_undefined		(uint32_t) (1 << ACTION_NUM_undefined)
 
 #define ANON_METHOD_ANONYMIZE		1
 #define ANON_METHOD_ZEROIZE		2
 #define ANON_METHOD_KEEPTYPEASNCC	3
+#define ANON_METHOD_KEEPTYPEGEONAMEID	4
 
 typedef struct {
 	const uint32_t number;
@@ -303,6 +312,8 @@ typedef struct {
 	{ ACTION_mac_to_eui64         , "geneui64"        , "Converts a MAC address to an EUI-64 address", "" },
 	{ ACTION_ipv4_to_6to4addr     , "conv6to4"        , "Converts IPv4 address <-> 6to4 IPv6 address (prefix)", "" },
 	{ ACTION_ipv4_to_nat64        , "convnat64"       , "Converts IPv4 address <-> NAT64 IPv6 address", "" },
+	{ ACTION_ipv6_to_mac          , "ipv6tomac"       , "Extracts MAC of an IPv6 address (if detected)", "" },
+	{ ACTION_ipv6_to_eui64        , "ipv6toeui64"     , "Extracts EUI64 of an IPv6 address (if detected)", "" },
 	{ ACTION_iid_token_to_privacy , "genprivacyiid"   , "Generates a privacy interface ID out of a given one (arg1) and a token (arg2)", "" },
 	{ ACTION_prefix_mac_to_ipv6   , "prefixmac2ipv6"  , "Generates an IPv6 address out of a prefix and a MAC address", "" },
 	{ ACTION_anonymize            , "anonymize"       , "Anonymize IPv4/IPv6 address without loosing much information", "" },
@@ -310,6 +321,7 @@ typedef struct {
 	{ ACTION_6rd_extract_ipv4     , "6rd_extract_ipv4", "Extract from 6rd address the include IPv4 address", "" },
 	{ ACTION_filter	              , "filter"          , "Filter addresses related to filter options", "" },
 	{ ACTION_test                 , "test"            , "Test address against given prefix or address", "" },
+	{ ACTION_addr_to_countrycode  , "addr2cc"         , "Converts IPv4/IPv6 address into Country Code", "" },
 };
 
 /* Possible action option map (required) */
@@ -319,9 +331,12 @@ typedef struct {
 	{ ACTION_mac_to_eui64		, 0 , 0},
 	{ ACTION_ipv4_to_6to4addr	, 0 , 0},
 	{ ACTION_ipv4_to_nat64		, 0 , 0},
+	{ ACTION_ipv6_to_mac		, 0 , 0},
+	{ ACTION_ipv6_to_eui64		, 0 , 0},
 	{ ACTION_iid_token_to_privacy	, 0 , 0},
 	{ ACTION_prefix_mac_to_ipv6	, 0 , 0},
 	{ ACTION_anonymize		, 0 , 0},
+	{ ACTION_addr_to_countrycode	, 0 , 0},
 	{ ACTION_6rd_local_prefix	, CMD_6rd_prefix, 0},
 	{ ACTION_6rd_local_prefix	, CMD_6rd_relay_prefix, 1 },
 	{ ACTION_6rd_extract_ipv4	, CMD_6rd_prefixlength, 0},
