@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : libipaddr.c
- * Version    : $Id: 88fd988adbd58f2a548f6fdd0364cd746c05e135 $
- * Copyright  : 2014-2015 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 581636ff92443b6d04a21fe94b5b09c41f15cf3d $
+ * Copyright  : 2014-2019 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Function library for generic IPv4/6 address handling
@@ -89,5 +89,13 @@ extern void libipaddr_clearall(ipv6calc_ipaddr *ipaddrp) {
         /* Clear valid flag */
         ipaddrp->flag_valid = 0;
 
+        /* Clear prefix */
+        ipaddrp->prefixlength = 0;
+        ipaddrp->flag_prefixuse = 0;
+
+        /* Clear typeinfo */
+        ipaddrp->typeinfo1 = 0;
+        ipaddrp->typeinfo2 = 0;
+
 	return;
 };
