@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv4addr.c
- * Version    : $Id: 777404b2dc6fbef4d32bc2be054dbc35fe0f38a3 $
- * Copyright  : 2002-2017 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: b2da5641d8dc6997a5ba05c1bd20888c3ea4e09c $
+ * Copyright  : 2002-2019 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  * License    : GNU GPL v2
  *
  * Information:
@@ -313,21 +313,45 @@ uint32_t ipv4addr_gettype(const ipv6calc_ipv4addr *ipv4addrp) {
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "Check for anonymized address, parity count c=%d", c);
 
 		if (((c & 0x1) ^ 0x1) == ((ipv4 >> 27) & 0x1)) {
-			// check country code (limited value)
+			// odd parity: check country code (limited value)
 			p = (ipv4 >> 17) & 0x3ff;
 
 			if ((p <= COUNTRYCODE_INDEX_LETTER_MAX) || (p == COUNTRYCODE_INDEX_UNKNOWN) || ((p >= COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MIN) && (p <= COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MAX))) {
-				DEBUGPRINT_NA(DEBUG_libipv4addr, "Address is an anonymized one");
+				DEBUGPRINT_NA(DEBUG_libipv4addr, "Address is an anonymized one (KeepType/ASN/CountryCode)");
 
 				type = IPV4_ADDR_ANONYMIZED | IPV4_ADDR_UNICAST| IPV4_ADDR_GLOBAL;
 
-				if ((ipv4 & 0x11800) == 0x11800) {
+				if ((ipv4 & 0x11fff) == 0x11800) {
 					DEBUGPRINT_NA(DEBUG_libipv4addr, "Address is a LISP unicast one");
 					type |= IPV4_ADDR_LISP;
 				};
 				goto END_ipv4addr_gettype;
 			};
+		} else  if (((c & 0x1) ^ 0x0) == ((ipv4 >> 27) & 0x1)) {
+			//even parity: check GeonameID source
+			p = (ipv4 >> 24) & 0x7;
 
+			if (p == 0x7) {
+				DEBUGPRINT_NA(DEBUG_libipv4addr, "Address is potentially an anonymized one (KeepType/GeonameID: LISP)");
+
+				if ((ipv4 & 0x11fff) == 0x11800) {
+					// 11 bit LISP information still not encoded
+					DEBUGPRINT_NA(DEBUG_libipv4addr, "Address is a LISP unicast one");
+
+					type = IPV4_ADDR_ANONYMIZED | IPV4_ADDR_UNICAST| IPV4_ADDR_GLOBAL | IPV4_ADDR_ANONYMIZED_GEONAMEID | IPV4_ADDR_LISP;
+
+					goto END_ipv4addr_gettype;
+				};
+			};
+
+			if (((p > IPV6CALC_DB_GEO_GEONAMEID_TYPE_UNKNOWN) \
+			     && p <= IPV6CALC_DB_GEO_GEONAMEID_TYPE_CITY)) {
+				DEBUGPRINT_NA(DEBUG_libipv4addr, "Address is an anonymized one (KeepGeonameID)");
+
+				type = IPV4_ADDR_ANONYMIZED | IPV4_ADDR_UNICAST| IPV4_ADDR_GLOBAL | IPV4_ADDR_ANONYMIZED_GEONAMEID;
+
+				goto END_ipv4addr_gettype;
+			};
 		} else {
 				DEBUGPRINT_NA(DEBUG_libipv4addr, "Address is not an detected anonymized one");
 		};
@@ -446,7 +470,7 @@ int addr_to_ipv4addrstruct(const char *addrstring, char *resultstring, const siz
 	addronlystring = strtok_r(tempstring, "/", ptrptr);
 
 	if ( addronlystring == NULL ) {
-		fprintf(stderr, "Strange input: %s\n", addrstring);
+		fprintf(stderr, "Strange input (extracting prefix length): %s\n", addrstring);
 		return (1);
 	};
 
@@ -852,8 +876,8 @@ int libipv4addr_anonymize(ipv6calc_ipv4addr *ipv4addrp, unsigned int mask, const
 	} else if ((ipv4addrp->typeinfo & IPV4_ADDR_BROADCAST) != 0) {
 		DEBUGPRINT_NA(DEBUG_libipv4addr, "skip anonymize (broadcast address)");
 
-	} else if ((method != ANON_METHOD_KEEPTYPEASNCC) || ((ipv4addrp->typeinfo & (IPV4_ADDR_UNICAST | IPV4_ADDR_GLOBAL)) != (IPV4_ADDR_UNICAST | IPV4_ADDR_GLOBAL))) {
-		// not ANON_METHOD_KEEPTYPEASNCC or not a global address
+	} else if (((method != ANON_METHOD_KEEPTYPEASNCC) && (method != ANON_METHOD_KEEPTYPEGEONAMEID)) || ((ipv4addrp->typeinfo & (IPV4_ADDR_UNICAST | IPV4_ADDR_GLOBAL)) != (IPV4_ADDR_UNICAST | IPV4_ADDR_GLOBAL))) {
+		// not ANON_METHOD_KEEPTYPEASNCC/ANON_METHOD_KEEPTYPEGEONAMEID or not a global address
 		if (((ipv4addrp->typeinfo & IPV4_ADDR_ANYCAST) != 0) && ((ipv4addrp->typeinfo & IPV4_ADDR_LISP) != 0)) {
 			if (mask < 24) {
 				mask = 24; // keeping address type
@@ -887,24 +911,24 @@ int libipv4addr_anonymize(ipv6calc_ipv4addr *ipv4addrp, unsigned int mask, const
 				ipv4addr_setdword(ipv4addrp, ipv4addr_getdword(ipv4addrp) & (0xffffffffu << ((unsigned int) 32 - mask)));
 			};
 		};
-	} else {
+	} else if (method == ANON_METHOD_KEEPTYPEASNCC) {
 		/* check for required database support */
 		if (libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEASNCC_IPV4_REQ_DB) == 0) {
 			DEBUGPRINT_NA(DEBUG_libipv4addr, "anonymization method not supported, db_wrapper reports too less features");
 			return(1);
 		};
 
-		DEBUGPRINT_NA(DEBUG_libipv4addr, "anonymize by keep information");
+		DEBUGPRINT_NA(DEBUG_libipv4addr, "anonymize by keep Type/ASN/CountryCode information");
 
 		CONVERT_IPV4ADDRP_IPADDR(ipv4addrp, ipaddr);
 
 		if (((ipv4addrp->typeinfo & IPV4_ADDR_UNICAST) != 0) && ((ipv4addrp->typeinfo & IPV4_ADDR_LISP) != 0)) {
 			as_num32_comp17 = 0x11800;
-			as_num32_comp17 |= (libipv6calc_db_wrapper_registry_num_by_ipv4addr(ipv4addrp) & 0x7) << 12;
+			as_num32_comp17 |= (libipv6calc_db_wrapper_registry_num_by_ipv4addr(ipv4addrp) & 0x7) << 13;
 			as_num32_comp17 |= 0x000; // TODO: map LISP information into 11 LSB
 		} else {
 			// get AS number
-			as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr);
+			as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr, NULL);
 			DEBUGPRINT_WA(DEBUG_libipv4addr, "result of AS number  retrievement: 0x%08x (%d)", as_num32, as_num32);
 
 			as_num32_comp17 = libipv6calc_db_wrapper_as_num32_comp17(as_num32);
@@ -943,7 +967,58 @@ int libipv4addr_anonymize(ipv6calc_ipv4addr *ipv4addrp, unsigned int mask, const
 
 		ipv4addr_anon |= ((c & 0x1) ^ 0x1) << 27;
 
-		DEBUGPRINT_WA(DEBUG_libipv4addr, "result anonymized IPv4 address: 0x%08x, bitcounts=%d", ipv4addr_anon, c);
+		DEBUGPRINT_WA(DEBUG_libipv4addr, "result anonymized (Type/ASN/CC) IPv4 address: 0x%08x, bitcounts=%d", ipv4addr_anon, c);
+
+		ipv4addr_setdword(ipv4addrp, ipv4addr_anon);
+	} else {
+		unsigned int GeonameID_type = IPV6CALC_DB_GEO_GEONAMEID_TYPE_UNKNOWN;
+		uint32_t GeonameID = IPV6CALC_DB_GEO_GEONAMEID_UNKNOWN;
+
+		/* check for required database support */
+		if (libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEGEONAMEID_IPV4_REQ_DB) == 0) {
+			DEBUGPRINT_NA(DEBUG_libipv4addr, "anonymization method not supported, db_wrapper reports too less features");
+			return(1);
+		};
+
+		DEBUGPRINT_NA(DEBUG_libipv4addr, "anonymize by keep GeonameID information");
+
+		CONVERT_IPV4ADDRP_IPADDR(ipv4addrp, ipaddr);
+
+		if (((ipv4addrp->typeinfo & IPV4_ADDR_UNICAST) != 0) && ((ipv4addrp->typeinfo & IPV4_ADDR_LISP) != 0)) {
+			GeonameID_type = 0x7;
+			GeonameID = 0x11800;
+			GeonameID |= (libipv6calc_db_wrapper_registry_num_by_ipv4addr(ipv4addrp) & 0x7) << 13;
+			GeonameID |= 0x000; // TODO: map LISP information into 11 LSB
+		} else {
+			// get GeonameID
+			GeonameID_type |= IPV6CALC_DB_GEO_GEONAMEID_TYPE_FLAG_24BIT;
+			GeonameID = libipv6calc_db_wrapper_GeonameID_by_addr(&ipaddr, NULL, &GeonameID_type);
+			DEBUGPRINT_WA(DEBUG_libipv4addr, "result of GeonameID retrievement: %d (0x%08x) (source: %d)", GeonameID, GeonameID, GeonameID_type);
+
+			if (GeonameID > 0xffffff) {
+				ERRORPRINT_WA("result of GeonameID retrievement: %d (source: %d) above 24-bit limit (fix code)", GeonameID, GeonameID_type);
+			};
+		};
+
+		// 0-3   ( 4 bits) : prefix 0xf0
+		// 4     ( 1 bit ) : parity bit (even parity)
+		// 5-7   ( 3 bits) : GeoNameID source - or 0x7 in case of LISP
+		// 8-31  (24 bits) : GeonameID (limited to 24 bit) - or Registry in case of LISP
+		ipv4addr_anon = 0xf0000000 | ((GeonameID_type << 24) & 0x07000000 ) | (GeonameID & 0x00ffffff);
+
+		// create parity bits
+		c = 0;
+		p = 0x00000001;
+		for (i = 0; i < 27; i++) {
+			if ((ipv4addr_anon & p) != 0) {
+				c++;
+			};
+			p <<= 1;
+		};
+
+		ipv4addr_anon |= ((c & 0x1) ^ 0x0) << 27;
+
+		DEBUGPRINT_WA(DEBUG_libipv4addr, "result anonymized (Type/GeonameID) IPv4 address: 0x%08x, bitcounts=%d", ipv4addr_anon, c);
 
 		ipv4addr_setdword(ipv4addrp, ipv4addr_anon);
 	};
@@ -963,9 +1038,12 @@ int libipv4addr_anonymize(ipv6calc_ipv4addr *ipv4addrp, unsigned int mask, const
 uint32_t ipv4addr_anonymized_get_as_num32(const ipv6calc_ipv4addr *ipv4addrp) {
 	if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
 		return(ASNUM_AS_UNKNOWN);
- 	} else if ((ipv4addrp->typeinfo & IPV4_ADDR_LISP) != 0) {
+	} else if ((ipv4addrp->typeinfo & IPV4_ADDR_LISP) != 0) {
 		// anonymized LISP can't save AS number
 		return(ASNUM_AS_UNKNOWN);
+ 	} else if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED_GEONAMEID) != 0) {
+		// GeonameID can't save AS number
+		return(ASNUM_AS_UNKNOWN);
 	};
 
 	return(libipv6calc_db_wrapper_as_num32_decomp17(ipv4addr_getdword(ipv4addrp) & 0x1ffff));
@@ -981,6 +1059,9 @@ uint32_t ipv4addr_anonymized_get_as_num32(const ipv6calc_ipv4addr *ipv4addrp) {
 uint16_t ipv4addr_anonymized_get_cc_index(const ipv6calc_ipv4addr *ipv4addrp) {
 	if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
 		return(COUNTRYCODE_INDEX_UNKNOWN);
+ 	} else if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED_GEONAMEID) != 0) {
+		// GeonameID can't save CountryCode
+		return(COUNTRYCODE_INDEX_UNKNOWN);
 	};
 
 	return((ipv4addr_getword(ipv4addrp, 0) & 0x7fe) >>1);
@@ -1405,7 +1486,7 @@ int ipv4addr_filter(const ipv6calc_ipv4addr *ipv4addrp, const s_ipv6calc_filter_
 	};
 
 	if (filter->filter_db_asn.active > 0) {
-		uint32_t asn = libipv4addr_as_num32_by_addr(ipv4addrp);
+		uint32_t asn = libipv4addr_as_num32_by_addr(ipv4addrp, NULL);
 
 		if (filter->filter_db_asn.active > 0) {
 			if (libipv6calc_db_asn_filter(asn, &filter->filter_db_asn) > 0) {
@@ -1466,7 +1547,7 @@ uint16_t libipv4addr_cc_index_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsign
  * in : *ipv4addrp = IPv4 address structure
  * out: 32-bit AS number
  */
-uint32_t libipv4addr_as_num32_by_addr(const ipv6calc_ipv4addr *ipv4addrp) {
+uint32_t libipv4addr_as_num32_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsigned int *data_source_ptr) {
 	uint32_t as_num32 = ASNUM_AS_UNKNOWN;
 	ipv6calc_ipaddr ipaddr;
 
@@ -1475,7 +1556,7 @@ uint32_t libipv4addr_as_num32_by_addr(const ipv6calc_ipv4addr *ipv4addrp) {
 	} else {
 		if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) == 1) {
 			CONVERT_IPV4ADDRP_IPADDR(ipv4addrp, ipaddr);
-			as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr);
+			as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr, data_source_ptr);
 		};
 	};
 
@@ -1496,19 +1577,28 @@ int libipv4addr_registry_num_by_addr(const ipv6calc_ipv4addr *ipv4addrp) {
 	uint16_t cc_index;
 
 	if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) != 0) {
-		DEBUGPRINT_NA(DEBUG_libipv4addr, "IPv4 is anonymized, extract registry from anonymized data");
-		// ASN -> Registry
-		// CC  -> Registry
+		if( (ipv4addrp->typeinfo & IPV4_ADDR_LISP) != 0) {
+			DEBUGPRINT_NA(DEBUG_libipv4addr, "IPv4 is anonymized LISP, extract registry from anonymized data");
+			// extract registry
+			uint32_t ipv4addr = ipv4addr_getdword(ipv4addrp);
+			registry = (ipv4addr >> 13) & 0x7;
+		} else if( (ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED_GEONAMEID) != 0) {
+			// GeonameID can't save Registry (exception: LISP)
+		} else {
+			DEBUGPRINT_NA(DEBUG_libipv4addr, "IPv4 is anonymized, extract registry from anonymized data");
+			// ASN -> Registry
+			// CC  -> Registry
 
-		/* retrieve registry via AS number from anonymized address (simple) */
-		as_num32 = libipv4addr_as_num32_by_addr(ipv4addrp);
-		if (as_num32 != ASNUM_AS_UNKNOWN) {
-			registry = libipv6calc_db_wrapper_registry_num_by_as_num32(as_num32);
-		};
-		if ((as_num32 == ASNUM_AS_UNKNOWN) || (registry == IPV4_ADDR_REGISTRY_ARIN)) {
-			/* retrieve registry via cc_index from anonymized address (simple, fallback) */
-			cc_index = libipv4addr_cc_index_by_addr(ipv4addrp, NULL);
-			registry = libipv6calc_db_wrapper_registry_num_by_cc_index(cc_index);
+			/* retrieve registry via AS number from anonymized address (simple) */
+			as_num32 = libipv4addr_as_num32_by_addr(ipv4addrp, NULL);
+			if (as_num32 != ASNUM_AS_UNKNOWN) {
+				registry = libipv6calc_db_wrapper_registry_num_by_as_num32(as_num32);
+			};
+			if ((as_num32 == ASNUM_AS_UNKNOWN) || (registry == IPV4_ADDR_REGISTRY_ARIN)) {
+				/* retrieve registry via cc_index from anonymized address (simple, fallback) */
+				cc_index = libipv4addr_cc_index_by_addr(ipv4addrp, NULL);
+				registry = libipv6calc_db_wrapper_registry_num_by_cc_index(cc_index);
+			};
 		};
 	} else {
 		if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_REGISTRY) == 1) {
@@ -1522,3 +1612,50 @@ int libipv4addr_registry_num_by_addr(const ipv6calc_ipv4addr *ipv4addrp) {
 	DEBUGPRINT_WA(DEBUG_libipv4addr, "registry=%d (0x%x)", registry, registry);
 	return(registry);
 };
+
+
+/*
+ * GeonameID of IPv4 address
+ *
+ * in : *ipv4addrp = IPv4 address structure
+ * mod: GeonameID_type_ptr
+ * out: GeonameID
+ */
+uint32_t libipv4addr_GeonameID_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsigned int *data_source_ptr, unsigned int *GeonameID_type_ptr) {
+	uint32_t GeonameID = IPV6CALC_DB_GEO_GEONAMEID_UNKNOWN;
+	unsigned int GeonameID_type = IPV6CALC_DB_GEO_GEONAMEID_TYPE_UNKNOWN;
+	unsigned int data_source = IPV6CALC_DB_SOURCE_UNKNOWN;
+	ipv6calc_ipaddr ipaddr;
+	uint32_t ipv4 = ipv4addr_getdword(ipv4addrp);
+
+	if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) != 0) {
+		if (((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED_GEONAMEID) != 0) \
+		    && ((ipv4addrp->typeinfo & IPV4_ADDR_LISP) == 0)) {
+			// GeonameID included
+			GeonameID = ipv4 & 0x00ffffff; // 24 bit LSB
+			GeonameID_type = (ipv4 & 0x07000000) >> 24;
+			DEBUGPRINT_WA(DEBUG_libipv4addr, "result of anonymized IPv4 GeonameID retrievement: %d (0x%08x) (source: %02x) (ipv4=%08x)", GeonameID, GeonameID, GeonameID_type, ipv4);
+		};
+	} else {
+		if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_GEONAMEID) == 1) {
+			// get GeonameID
+			CONVERT_IPV4ADDRP_IPADDR(ipv4addrp, ipaddr);
+			GeonameID = libipv6calc_db_wrapper_GeonameID_by_addr(&ipaddr, &data_source, &GeonameID_type);
+			DEBUGPRINT_WA(DEBUG_libipv4addr, "result of GeonameID retrievement: %d (0x%08x) (source: %02x)", GeonameID, GeonameID, GeonameID_type);
+		} else {
+			DEBUGPRINT_NA(DEBUG_libipv4addr, "No support available for IPV6CALC_DB_IPV4_TO_GEONAMEID");
+		};
+	};
+
+	DEBUGPRINT_WA(DEBUG_libipv4addr, "GeonameID=%d (0x%x)", GeonameID, GeonameID);
+
+	if (data_source_ptr != NULL) {
+		*data_source_ptr = data_source;
+	};
+
+	if (GeonameID_type_ptr != NULL) {
+		*GeonameID_type_ptr = GeonameID_type;
+	};
+
+	return(GeonameID);
+};
