@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6addr.h
- * Version    : $Id: 3f20ce854f6221680fd5023873bf0fdc48d50ec8 $
- * Copyright  : 2001-2017 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: a7b412b2d106955ba6b682c2e8be15d13b3d1ffc $
+ * Copyright  : 2001-2019 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  * License    : GNU GPL v2
  *
  * Information:
@@ -45,17 +45,36 @@
  * SLA/NLA prefix part anonymization is done by replacing with pattern a909a909
  *   p = number of nibbles anonymized in prefix
  *   		0 : no nibble of prefix is anonymized
- *   		f : Prefix anonymization with method=kp
+ *   		f : Prefix anonymization with method=kp|kg
  *
- * Prefix anonymization in case of method=kp: p=0x0f, but skipped for
+ * Prefix anonymization, but skipped for
  *  - LISP anycast
+ * in case of method=kp: p=0x0f
  * a909:ccca:aaaa:aaaC  (C = 4-bit checksum)
  *                      ccc      -> 10-bit Country Code mapping [A-Z]*[A-Z0-9] (936)
  *                                   0x3FD = LISP
  *                                   0x3FE = unknown country
  *                                   0x3FF - 16 + REGISTRY_6BONE && ASN=0 = 6bone
  *                                   0x000-0x3A7: c1= c / 36, c2 = c % 36
+ *                               -> 2 leftmost bit are |0 0|
  *                      aaaaaaaa -> 32-bit ASN
+ *
+ * in case of method=kg: p=0x0f
+ * a909:sssg:gggg:gggC  (C = 4-bit checksum)
+ *                      sss      -> 10-bit source mapping
+ *                                   GeonameID source information
+ *                                   0x000 = unknown
+ *			             0x001 = continent  (prio: lowest)
+ *                                   0x002 = country
+ *                                   0x003 = state/prov
+ *                                   0x004 = district
+ *                                   0x005 = city       (prio: highest)
+ *                                   0x006 = (reserved)
+ *                                   0x007 = LISP
+ *                                   0x0r. = registry
+ *                               -> 2 leftmost bit are |0 1|
+ *                      gggggggg -> 32-bit GeonameID
+ *                                   0x11800 = LISP
  */
 #define ANON_TOKEN_VALUE_00_31		(uint32_t) 0xa9090000u
 #define ANON_TOKEN_MASK_00_31		(uint32_t) 0xff0f0000u
@@ -130,12 +149,19 @@
 
 // Prefix anonymization on method=kp
 #define ANON_METHOD_KEEPTYPEASNCC_IPV6_REQ_DB	(IPV6CALC_DB_IPV6_TO_CC | IPV6CALC_DB_IPV6_TO_AS)
+// Prefix anonymization on method=kg
+#define ANON_METHOD_KEEPTYPEGEONAMEID_IPV6_REQ_DB	(IPV6CALC_DB_IPV6_TO_GEONAMEID)
 
 #define ANON_PREFIX_CCINDEX_DWORD	0
 #define ANON_PREFIX_CCINDEX_SHIFT	4
 #define ANON_PREFIX_CCINDEX_MASK	0x3ff
 #define ANON_PREFIX_CCINDEX_XOR		0x0
 
+#define ANON_PREFIX_GEONAMEID_TYPE_DWORD	0
+#define ANON_PREFIX_GEONAMEID_TYPE_SHIFT	4
+#define ANON_PREFIX_GEONAMEID_TYPE_MASK		0x3ff
+#define ANON_PREFIX_GEONAMEID_TYPE_XOR		0x0
+
 #define ANON_PREFIX_ASN32_MSB_DWORD	0
 #define ANON_PREFIX_ASN32_MSB_SHIFT	0
 #define ANON_PREFIX_ASN32_MSB_AMOUNT	4
@@ -148,6 +174,18 @@
 #define ANON_PREFIX_ASN32_LSB_MASK	((1 << ANON_PREFIX_ASN32_LSB_AMOUNT) - 1)
 #define ANON_PREFIX_ASN32_LSB_XOR	0x09090000
 
+#define ANON_PREFIX_GEONAMEID_MSB_DWORD	0
+#define ANON_PREFIX_GEONAMEID_MSB_SHIFT	0
+#define ANON_PREFIX_GEONAMEID_MSB_AMOUNT	4
+#define ANON_PREFIX_GEONAMEID_MSB_MASK	((1 << ANON_PREFIX_GEONAMEID_MSB_AMOUNT) - 1)
+#define ANON_PREFIX_GEONAMEID_MSB_XOR	0x0000000a
+
+#define ANON_PREFIX_GEONAMEID_LSB_DWORD	1
+#define ANON_PREFIX_GEONAMEID_LSB_SHIFT	4
+#define ANON_PREFIX_GEONAMEID_LSB_AMOUNT	28
+#define ANON_PREFIX_GEONAMEID_LSB_MASK	((1 << ANON_PREFIX_GEONAMEID_LSB_AMOUNT) - 1)
+#define ANON_PREFIX_GEONAMEID_LSB_XOR	0x09090000
+
 #define ANON_PREFIX_FLAGS_DWORD		0
 #define ANON_PREFIX_FLAGS_SHIFT		14
 #define ANON_PREFIX_FLAGS_MASK		0x3
@@ -160,8 +198,11 @@
 #define ANON_PREFIX_TOKEN_VALUE		0xa909		// fix
 
 // Payload selector
-#define ANON_PREFIX_PAYLOAD_CCINDEX	1
-#define ANON_PREFIX_PAYLOAD_ASN32	2
+#define ANON_PREFIX_PAYLOAD_FLAGS		0
+#define ANON_PREFIX_PAYLOAD_CCINDEX		1
+#define ANON_PREFIX_PAYLOAD_ASN32		2
+#define ANON_PREFIX_PAYLOAD_GEONAMEID		3
+#define ANON_PREFIX_PAYLOAD_GEONAMEID_TYPE	4
 
 
 /* IPv6 address storage structure */
@@ -310,6 +351,8 @@ typedef struct {
 #define IPV6_ADDR_TYPE2_LISP			(uint32_t) 0x00010000U	/* IPv6 LISP (RFC6830) */
 #define IPV6_ADDR_TYPE2_LISP_PETR		(uint32_t) 0x00020000U	/* IPv6 LISP Proxy Egress Tunnel Routers (PETRY) Anycast */
 #define IPV6_ADDR_TYPE2_LISP_MAP_RESOLVER	(uint32_t) 0x00040000U	/* IPv6 LISP Map Resolver Anycast */
+#define IPV6_ADDR_TYPE2_ANON_MASKED_PREFIX	(uint32_t) 0x00080000U	/* IPv6 partially masked prefix */
+#define IPV6_ADDR_TYPE2_ANONYMIZED_GEONAMEID	(uint32_t) 0x00100000U  /* IPv6 prefix anonymized contains GeonameID */
 
 // IPv4 address extractor selector
 #define IPV6_ADDR_SELECT_IPV4_DEFAULT		0
@@ -359,6 +402,8 @@ typedef struct {
 	{ IPV6_ADDR_TYPE2_LISP	 		, "lisp" },
 	{ IPV6_ADDR_TYPE2_LISP_PETR		, "lisp-proxyegresstunnelrouter-anycast" },
 	{ IPV6_ADDR_TYPE2_LISP_MAP_RESOLVER	, "lisp-mapresolver-anycast" },
+	{ IPV6_ADDR_TYPE2_ANON_MASKED_PREFIX    , "anonymized-masked-prefix" },
+	{ IPV6_ADDR_TYPE2_ANONYMIZED_GEONAMEID  , "anonymized-geonameid" },
 };
 
 /* Registries */
@@ -403,8 +448,7 @@ extern void ipv6addr_copy(ipv6calc_ipv6addr *ipv6addrp_dst, const ipv6calc_ipv6a
 
 extern int ipv6addr_compare(const ipv6calc_ipv6addr *ipv6addrp1, const ipv6calc_ipv6addr *ipv6addrp2, const uint16_t compare_flags);
 
-extern uint32_t ipv6addr_gettype(const ipv6calc_ipv6addr *ipv6addrp, uint32_t *typeinfo2p);
-extern void ipv6addr_settype(ipv6calc_ipv6addr *ipv6addrp, int flag_reset);
+extern void ipv6addr_settype(ipv6calc_ipv6addr *ipv6addrp);
 
 extern int  addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv6addr *ipv6addrp);
 extern int  addrliteral_to_ipv6addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv6addr *ipv6addrp);
@@ -435,5 +479,6 @@ extern void ipv6addr_filter_clear(s_ipv6calc_filter_ipv6addr *filter);
 extern int  libipv6addr_get_included_ipv4addr(const ipv6calc_ipv6addr *ipv6addrp, ipv6calc_ipv4addr *ipv4addrp, const int selector);
 
 extern uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp, unsigned int *data_source_ptr);
-extern uint32_t libipv6addr_as_num32_by_addr(const ipv6calc_ipv6addr *ipv6addrp);
+extern uint32_t libipv6addr_as_num32_by_addr(const ipv6calc_ipv6addr *ipv6addrp, unsigned int *data_source_ptr);
+extern uint32_t libipv6addr_GeonameID_by_addr(const ipv6calc_ipv6addr *ipv6addrp, unsigned int *data_source_ptr, unsigned int *GeonameID_type_ptr);
 extern int libipv6addr_registry_num_by_addr(const ipv6calc_ipv6addr *ipv6addrp);
