@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : librfc1924.c
- * Version    : $Id: 288cc1921031e011601609d286d5a7402acafbed $
- * Copyright  : 2001-2017 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 3944d1bf78c2fd522c5056b42a50fa44021319e9 $
+ * Copyright  : 2001-2019 by Peter Bieringer <pb (at) bieringer.de>
  *              and 2006 by Niko Tyni <ntyni (at) iki.fi>
  *
  * Information:
@@ -169,7 +169,7 @@ int base85_to_ipv6addrstruct(const char *addrstring, char *resultstring, const s
 		ipv6addr_setword(ipv6addrp, (unsigned int) i, (unsigned int) result[i]);
 	};
 	
-	ipv6addr_settype(ipv6addrp, 1); /* Set typeinfo */
+	ipv6addr_settype(ipv6addrp); /* Set typeinfo */
 	
 	ipv6addrp->flag_valid = 1;
 
