@@ -2,8 +2,8 @@
 #
 # Project    : ipv6calc
 # File       : test_mod_ipv6calc.sh
-# Version    : $Id: 2fd57e46c16d2e6bda3a19164d69682492522104 $
-# Copyright  : 2015-2017 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: 1e0bfde5ad44f37bc229f14f9ba9b6e27055c2b0 $
+# Copyright  : 2015-2019 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc conversions
 
@@ -104,13 +104,16 @@ create_apache_root_and_start() {
 
 	## disable databases by option
 	[ "$disable_geoip" = "1" ]       && perl -pi -e 's/#(ipv6calcOption\s+db-geoip-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
+	[ "$disable_geoip2" = "1" ]      && perl -pi -e 's/#(ipv6calcOption\s+db-geoip2-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
 	[ "$disable_ip2location" = "1" ] && perl -pi -e 's/#(ipv6calcOption\s+db-ip2location-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
 	[ "$disable_dbip" = "1" ]        && perl -pi -e 's/#(ipv6calcOption\s+db-dbip-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
+	[ "$disable_dbip2" = "1" ]       && perl -pi -e 's/#(ipv6calcOption\s+db-dbip2-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
 	[ "$disable_external" = "1" ]    && perl -pi -e 's/#(ipv6calcOption\s+db-external-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
 
 	[ "$action_asn" = "0" ]    && perl -pi -e 's/(ipv6calcActionAsn\s+).*$/$1 off/g'         $dir_base/conf.d/ipv6calc.conf
 	[ "$action_cc" = "0" ]     && perl -pi -e 's/(ipv6calcActionCountrycode\s+).*$/$1 off/g' $dir_base/conf.d/ipv6calc.conf
 	[ "$action_reg" = "0" ]    && perl -pi -e 's/(ipv6calcActionRegistry\s+).*$/$1 off/g'    $dir_base/conf.d/ipv6calc.conf
+	[ "$action_gid" = "0" ]    && perl -pi -e 's/(ipv6calcActionGeonameid\s+).*$/$1 off/g'   $dir_base/conf.d/ipv6calc.conf
 	[ "$action_anon" = "0" ]   && perl -pi -e 's/(ipv6calcActionAnonymize\s+).*$/$1 off/g'   $dir_base/conf.d/ipv6calc.conf
 
 
@@ -297,13 +300,16 @@ $(basename "$0") [<options>] [-S|-K|-W]
 	-c	show effective module config options
 
 	-g	disable GeoIP
+	-G	disable GeoIP(MaxMindDB)
 	-i	disable IP2Location
-	-d	disable DBIP.com
+	-d	disable db-ip.com
+	-D	disable db-ip.com(MaxMindDB)
 	-e	disable external databases
 
 	-A	disable action ASN
 	-C	disable action CountryCode
 	-R	disable action Registry
+	-I	disable action GeonameID
 	-N	disable action Anonymization
 
 	-b <base directory
@@ -314,7 +320,7 @@ END
 }
 
 #### Options
-while getopts "rACRNca:fSKWb:mlgideh\?" opt; do
+while getopts "IDGrACRNca:fSKWb:mlgideh\?" opt; do
 	case $opt in
 	    b)
 		if [ -d "$OPTARG" ]; then
@@ -338,12 +344,18 @@ while getopts "rACRNca:fSKWb:mlgideh\?" opt; do
 	    g)
 		disable_geoip=1
 		;;
+	    G)
+		disable_geoip2=1
+		;;
 	    i)
 		disable_ip2location=1
 		;;
 	    d)
 		disable_dbip=1
 		;;
+	    D)
+		disable_dbip2=1
+		;;
 	    e)
 		disable_external=1
 		;;
@@ -368,6 +380,9 @@ while getopts "rACRNca:fSKWb:mlgideh\?" opt; do
 	    R)
 		action_reg="0"
 		;;
+	    I)
+		action_gid="0"
+		;;
 	    N)
 		action_anon="0"
 		;;
