@@ -4,8 +4,8 @@
 #
 # Project    : ipv6calc/DBIP
 # File       : DBIP-generate-db.pl
-# Version    : $Id: eeaa396bc045a167428c821a9088b488e5ff8a35 $
-# Copyright  : 2014-2017 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: 2237481ed6664401d82fbcd3afb04e8ae670b425 $
+# Copyright  : 2014-2018 by Peter Bieringer <pb (at) bieringer.de>
 # License    : GNU GPL version 2
 #
 # Supported formats (https://db-ip.com/db/)
@@ -97,13 +97,15 @@ if (! -d $dir_output) {
 my $type;
 my $date;
 my $type_string;
+my $lite;
 
-if ($file_input !~ /^(.*\/)?dbip-(city|country|isp|location|full)-([0-9]{4})-([0-9]{2})(-(test|sample))?\.csv(\.gz)?$/o) {
+if ($file_input !~ /^(.*\/)?dbip-(city|country|isp|location|full)(-lite)?-([0-9]{4})-([0-9]{2})(-(test|sample))?\.csv(\.gz)?$/o) {
 	print "ERROR : input file name is not a valid dbip filename: $file_input\n";
 	exit 1;
 };
 
-$date = $3 . $4 . "01";
+$date = $4 . $5 . "01";
+$lite = $3;
 $type_string = $2;
 
 if ($file_input =~ /\.gz$/o) {
@@ -231,7 +233,7 @@ while (<$FILE>) {
 	};
 
 	# replace escaped quotes to avoid confusing CSV parser
-	$line =~ s/\\\\\\"/'/g;
+	#$line =~ s/\\\\\\"/'/g;
 
 	# replace double (partially escaped) quotes to avoid confusing CSV parser
 	$line =~ s/"\\"/"/g;
@@ -259,7 +261,7 @@ while (<$FILE>) {
 
 	if ($type == 1000) {
 		# country
-		if ($line !~ /^"([0-9a-fA-F.:]*)","([0-9a-fA-F.:]*)","([A-Z]{0,2})"/o) {
+		if ($line !~ /^"?([0-9a-fA-F.:]*)"?,"?([0-9a-fA-F.:]*)"?,"?([A-Z]{0,2})"?/o) {
 			print "ERROR : unexpected line in file (line: $linecounter): $line\n";
 			exit 1;	
 		};
@@ -268,7 +270,7 @@ while (<$FILE>) {
 		$cc    = $3;
 	} elsif ($type == 1010) {
 		# city
-		if ($line !~ /^"([0-9a-fA-F.:]*)","([0-9a-fA-F.:]*)","([A-Z]{0,2})","([^"]*)","([^"]*)"/o) {
+		if ($line !~ /^"?([0-9a-fA-F.:]*)"?,"?([0-9a-fA-F.:]*)"?,"?([A-Z]{0,2})"?,"?([^"]*)"?,"?([^"]*)"?/o) {
 			print "ERROR : unexpected line in file (line: $linecounter): $line\n";
 			exit 1;	
 		};
